@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcart.h,v 1.34.2.2 2009/11/19 17:56:44 cvs Exp $
+//      $Id: rdcart.h,v 1.39.6.5.2.1 2014/03/19 22:12:58 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -22,10 +22,13 @@
 
 #include <qdatetime.h>
 
+#include <rdconfig.h>
 #include <rdwavedata.h>
 
 #include <rdcut.h>
 #include <rddb.h>
+#include <rduser.h>
+#include <rdstation.h>
 
 #ifndef RDCART_H
 #define RDCART_H
@@ -42,44 +45,50 @@ class RDCart
   enum Validity {NeverValid=0,ConditionallyValid=1,AlwaysValid=2,
 		 EvergreenValid=3};
   RDCart(unsigned number);
+  ~RDCart();
   bool exists() const;
   bool selectCut(QString *cut) const;
   bool selectCut(QString *cut,const QTime &time) const;
   RDCart::Type type() const;
-  void setType(RDCart::Type type) const;
+  void setType(RDCart::Type type);
   unsigned number() const;
   QString groupName() const;
-  void setGroupName(const QString &name) const;
+  void setGroupName(const QString &name);
   QString title() const;
-  void setTitle(const QString &title) const;
+  void setTitle(const QString &title);
   QString artist() const;
-  void setArtist(const QString &name) const;
+  void setArtist(const QString &name);
   QString album() const;
-  void setAlbum(const QString &album) const;
-  QDate year() const;
-  void setYear(const QDate &date) const;
-  void setYear() const;
+  void setAlbum(const QString &album);
+  int year() const;
+  void setYear(int year=-1);
   QString schedCodes() const;
   void setSchedCodes(const QString &sched_codes) const;
   void updateSchedCodes(const QString &add_codes,const QString &remove_codes) const;
+  QString conductor() const;
+  void setConductor(const QString &cond);
   QString label() const;
-  void setLabel(const QString &label) const;
+  void setLabel(const QString &label);
   QString client() const;
-  void setClient(const QString &client) const;
+  void setClient(const QString &client);
   QString agency() const;
-  void setAgency(const QString &agency) const;
+  void setAgency(const QString &agency);
   QString publisher() const;
-  void setPublisher(const QString &publisher) const;
+  void setPublisher(const QString &publisher);
   QString composer() const;
-  void setComposer(const QString &composer) const;
+  void setComposer(const QString &composer);
   QString userDefined() const;
-  void setUserDefined(const QString &string) const;
+  void setUserDefined(const QString &string);
+  QString songId() const;
+  void setSongId(const QString &id);
+  unsigned beatsPerMinute() const;
+  void setBeatsPerMinute(unsigned bpm);
   RDCart::UsageCode usageCode() const;
   void setUsageCode(RDCart::UsageCode code);
   QString notes() const;
-  void setNotes(const QString &notes) const;
+  void setNotes(const QString &notes);
   unsigned forcedLength() const;
-  void setForcedLength(unsigned length) const;
+  void setForcedLength(unsigned length);
   unsigned lengthDeviation() const;
   void setLengthDeviation(unsigned length) const;
   unsigned calculateAverageLength(unsigned *max_dev=0) const;
@@ -98,35 +107,44 @@ class RDCart
   RDCart::Validity validity() const;
   void setValidity(RDCart::Validity state);
   QDateTime startDateTime() const;
-  void setStartDateTime(const QDateTime &time) const;
-  void setStartDateTime() const;
+  void setStartDateTime(const QDateTime &time);
+  void setStartDateTime();
   QDateTime endDateTime() const;
-  void setEndDateTime(const QDateTime &time) const;
-  void setEndDateTime() const;
+  void setEndDateTime(const QDateTime &time);
+  void setEndDateTime();
   bool enforceLength() const;
-  void setEnforceLength(bool state) const;
+  void setEnforceLength(bool state);
   bool preservePitch() const;
   void setPreservePitch(bool state) const;
   bool asyncronous() const;
   void setAsyncronous(bool state) const;
   QString owner() const;
   void setOwner(const QString &owner) const;
+  bool useEventLength() const;
+  void setUseEventLength(bool state) const;
   QString macros() const;
   void setMacros(const QString &cmds) const;
-  void getMetadata(RDWaveData *data);
-  void setMetadata(RDWaveData *data);
-  void updateLength() const;
-  void updateLength(bool enforce_length,unsigned length) const;
+  bool validateLengths(int len) const;
+  void getMetadata(RDWaveData *data) const;
+  void setMetadata(const RDWaveData *data);
+  QString xml(bool include_cuts) const;
+  void updateLength();
+  void updateLength(bool enforce_length,unsigned length);
   void resetRotation() const;
-  int addCut(unsigned format,unsigned samprate,
-	     unsigned bitrate,unsigned chans) const;
-  void removeAllCuts();
-  void removeCut(const QString &cutname);
-  bool create(const QString &groupname,RDCart::Type type) const;
-  void remove() const;
+  void writeTimestamp();
+  int addCut(unsigned format,unsigned bitrate,unsigned chans,
+	     const QString &isci="",QString desc="");
+  bool removeAllCuts(RDStation *station,RDUser *user,RDConfig *config);
+  bool removeCut(RDStation *station,RDUser *user,const QString &cutname,
+		 RDConfig *config);
+  bool removeCutAudio(RDStation *station,RDUser *user,
+		      const QString &cutname,RDConfig *config) const;
+  bool create(const QString &groupname,RDCart::Type type);
+  bool remove(RDStation *station,RDUser *user,RDConfig *config) const;
   static bool exists(unsigned cartnum);
   static QString playOrderText(RDCart::PlayOrder order);
   static QString usageText(RDCart::UsageCode usage);
+  static QString typeText(RDCart::Type type);
   
  private:
   QString GetNextCut(RDSqlQuery *q) const;
@@ -140,6 +158,7 @@ class RDCart
   void SetRow(const QString &param,const QDate &value) const;
   void SetRow(const QString &param) const;
   unsigned cart_number;
+  bool metadata_changed;
 };
 
 
