@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcut_dialog.cpp,v 1.25.2.2 2009/08/04 20:56:49 cvs Exp $
+//      $Id: rdcut_dialog.cpp,v 1.31.4.2 2013/11/15 18:24:08 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,6 +20,9 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <stdlib.h>
+#include <stdio.h>
+
 #include <qpushbutton.h>
 #include <qlabel.h>
 #include <qsqlquery.h>
@@ -30,7 +33,9 @@
 #include <rdcart_search_text.h>
 #include <rdtextvalidator.h>
 #include <rdadd_cart.h>
+#include <rdprofile.h>
 #include <rddb.h>
+
 //
 // Icons
 //
@@ -38,18 +43,20 @@
 #include "../icons/rml5.xpm"
 
 
-RDCutDialog::RDCutDialog(QString *cutname,RDStation *station,QString *filter,
-			 QString *group,QString username,bool show_clear,
-			 bool allow_add,bool exclude_tracks,
-			 QWidget *parent,const char *name)
+RDCutDialog::RDCutDialog(QString *cutname,RDStation *station,RDSystem *system,
+			 QString *filter,QString *group,QString *schedcode,
+			 QString username,bool show_clear,bool allow_add,
+			 bool exclude_tracks,QWidget *parent,const char *name)
   : QDialog(parent,name,true)
 {
   cut_cutname=cutname;
   cut_exclude_tracks=exclude_tracks;
   cut_group=group;
+  cut_schedcode=schedcode;
   cut_username=username;
   cut_allow_clear=show_clear;
   cut_filter_mode=station->filterMode();
+  cut_system=system;
 
   if(filter==NULL) {
     cut_filter=new QString();
@@ -84,11 +91,6 @@ RDCutDialog::RDCutDialog(QString *cutname,RDStation *station,QString *filter,
   setMinimumHeight(sizeHint().height());
   setMaximumHeight(sizeHint().height());
 
-  //
-  // Text Validator
-  //
-  RDTextValidator *validator=new RDTextValidator(this,"validator");
-
   //
   // Progress Dialog
   //
@@ -108,7 +110,6 @@ RDCutDialog::RDCutDialog(QString *cutname,RDStation *station,QString *filter,
   // Filter Selector
   //
   cut_filter_edit=new QLineEdit(this,"cut_filter_edit");
-  cut_filter_edit->setValidator(validator);
   label=new QLabel(cut_filter_edit,tr("Cart Filter:"),this,"cut_filter_label");
   label->setGeometry(10,10,85,20);
   label->setAlignment(AlignRight|AlignVCenter);
@@ -138,19 +139,48 @@ RDCutDialog::RDCutDialog(QString *cutname,RDStation *station,QString *filter,
   // Group Selector
   //
   cut_group_box=new QComboBox(this,"cut_clear_box");
-  cut_group_box->setGeometry(100,35,140,20);
+  cut_group_box->setGeometry(100,40,140,20);
   label=new QLabel(cut_filter_edit,tr("Group:"),this,"cut_group_label");
-  label->setGeometry(10,35,85,20);
+  label->setGeometry(10,40,85,20);
   label->setAlignment(AlignRight|AlignVCenter);
   label->setFont(label_font);
   connect(cut_group_box,SIGNAL(activated(const QString &)),
 	  this,SLOT(groupActivatedData(const QString &)));
 
+  //
+  // Scheduler Code Selector
+  //
+  cut_schedcode_box=new QComboBox(this,"cut_schedcode_box");
+  cut_schedcode_box->setGeometry(380,40,sizeHint().width()-390,20);
+  cut_schedcode_label=new QLabel(cut_schedcode_box,tr("Scheduler Code:"),
+			   this,"cut_schedcode_label");
+  cut_schedcode_label->setGeometry(260,40,115,20);
+  cut_schedcode_label->setAlignment(AlignRight|AlignVCenter);
+  cut_schedcode_label->setFont(label_font);
+  connect(cut_schedcode_box,SIGNAL(activated(const QString &)),
+	  this,SLOT(groupActivatedData(const QString &)));
+
+  //
+  // Search Limit Checkbox
+  //
+  cart_limit_box=new QCheckBox(this,"cart_limit_box");
+  cart_limit_box->setGeometry(100,72,15,15);
+  cart_limit_box->setChecked(true);
+  label=new QLabel(cart_limit_box,tr("Show Only First")+
+		   QString().sprintf(" %d ",
+		   RD_LIMITED_CART_SEARCH_QUANTITY)+tr("Matches"),
+		   this,"cart_limit_label");
+  label->setGeometry(120,70,300,20);
+  label->setAlignment(AlignLeft|AlignVCenter);
+  label->setFont(label_font);
+  connect(cart_limit_box,SIGNAL(stateChanged(int)),
+	  this,SLOT(limitChangedData(int)));
+
   //
   // Cart List
   //
   cut_cart_list=new RDListView(this,"cut_cart_list");
-  cut_cart_list->setGeometry(10,90,300,200);
+  cut_cart_list->setGeometry(10,120,300,200);
   cut_cart_list->setAllColumnsShowFocus(true);
   cut_cart_list->setItemMargin(5);
   connect(cut_cart_list,SIGNAL(selectionChanged()),
@@ -158,14 +188,16 @@ RDCutDialog::RDCutDialog(QString *cutname,RDStation *station,QString *filter,
   connect(cut_cart_list,SIGNAL(clicked(QListViewItem *)),
 	  this,SLOT(cartClickedData(QListViewItem *)));
   label=new QLabel(cut_cart_list,tr("Carts"),this,"cut_cart_label");
-  label->setGeometry(15,70,100,20);
+  label->setGeometry(15,100,100,20);
   label->setFont(label_font);
   cut_cart_list->addColumn("");
   cut_cart_list->setColumnAlignment(0,Qt::AlignHCenter);
   cut_cart_list->addColumn(tr("NUMBER"));
+
   cut_cart_list->setColumnAlignment(1,Qt::AlignHCenter);
   cut_cart_list->addColumn(tr("TITLE"));
   cut_cart_list->setColumnAlignment(2,Qt::AlignLeft);
+
   cut_cart_list->addColumn(tr("GROUP"));
   cut_cart_list->setColumnAlignment(3,Qt::AlignCenter);
 
@@ -173,14 +205,15 @@ RDCutDialog::RDCutDialog(QString *cutname,RDStation *station,QString *filter,
   // Cut List
   //
   cut_cut_list=new QListView(this,"cut_cut_list");
-  cut_cut_list->setGeometry(320,90,sizeHint().width()-330,200);
+  cut_cut_list->setGeometry(320,120,sizeHint().width()-330,200);
   cut_cut_list->setAllColumnsShowFocus(true);
   cut_cut_list->setItemMargin(5);
   label=new QLabel(cut_cut_list,tr("Cuts"),this,"cut_cut_label");
-  label->setGeometry(325,70,100,20);
+  label->setGeometry(325,100,100,20);
   label->setFont(label_font);
   cut_cut_list->addColumn(tr("DESCRIPTION"));
   cut_cut_list->setColumnAlignment(0,Qt::AlignLeft);
+
   cut_cut_list->addColumn(tr("NUMBER"));
   cut_cut_list->setColumnAlignment(1,Qt::AlignLeft);
 
@@ -268,7 +301,7 @@ RDCutDialog::~RDCutDialog()
 
 QSize RDCutDialog::sizeHint() const
 {
-  return QSize(550,370);
+  return QSize(550,400);
 }
 
 
@@ -278,6 +311,13 @@ QSizePolicy RDCutDialog::sizePolicy() const
 }
 
 
+int RDCutDialog::exec()
+{
+  LoadState();
+  return QDialog::exec();
+}
+
+
 void RDCutDialog::filterChangedData(const QString &str)
 {
   cut_search_button->setEnabled(true);
@@ -305,6 +345,12 @@ void RDCutDialog::groupActivatedData(const QString &str)
 }
 
 
+void RDCutDialog::limitChangedData(int state)
+{
+  filterChangedData("");
+}
+
+
 void RDCutDialog::cartClickedData(QListViewItem *)
 {
   cut_ok_button->setEnabled(true);
@@ -353,7 +399,7 @@ void RDCutDialog::addButtonData()
   int cart_num=-1;
 
   RDAddCart *add_cart=new RDAddCart(&cart_group,&cart_type,&cart_title,
-				    cut_username,this);
+				    cut_username,cut_system,this);
   if((cart_num=add_cart->exec())<0) {
     delete add_cart;
     return;
@@ -396,6 +442,10 @@ void RDCutDialog::okData()
       if(cut_group!=NULL) {
 	*cut_group=cut_group_box->currentText();
       }
+      if(cut_schedcode!=NULL) {
+	*cut_schedcode=cut_schedcode_box->currentText();
+      }
+      SaveState();
       done(0);
     }
     return;
@@ -408,12 +458,14 @@ void RDCutDialog::okData()
   if(cut_group!=NULL) {
     *cut_group=cut_group_box->currentText();
   }
+  SaveState();
   done(0);
 }
 
 
 void RDCutDialog::cancelData()
 {
+  SaveState();
   done(1);
 }
 
@@ -434,17 +486,27 @@ void RDCutDialog::RefreshCarts()
   if(!cut_cutname->isEmpty()) {
   }
   cut_cart_list->clear();
-  if(group==QString("ALL")) {
+  if(group==QString(tr("ALL"))) {
     group="";
   }
+  QString schedcode="";
+  if(cut_schedcode_box->currentText()!=tr("ALL")) {
+    schedcode=cut_schedcode_box->currentText();
+  }
   sql=QString().sprintf("select CART.NUMBER,CART.TITLE,CART.GROUP_NAME,\
-                         GROUPS.COLOR from CART left join GROUPS \
+                         GROUPS.COLOR,CART.TYPE from CART left join GROUPS \
                          on CART.GROUP_NAME=GROUPS.NAME \
-                         where (%s)&&(CART.TYPE=1)",
-	      (const char *)RDCartSearchText(cut_filter_edit->text(),group).utf8());
+                         where (%s)&&((CART.TYPE=%u))",
+			(const char *)RDCartSearchText(cut_filter_edit->text(),
+						       group,schedcode.utf8(),
+						       false),
+			RDCart::Audio);
   if(cut_exclude_tracks) {
     sql+="&&(CART.OWNER is null)";
   }
+  if(cart_limit_box->isChecked()) {
+    sql+=QString().sprintf(" limit %d",RD_LIMITED_CART_SEARCH_QUANTITY);
+  }
   q=new RDSqlQuery(sql);
   int step=0;
   int count=0;
@@ -452,7 +514,15 @@ void RDCutDialog::RefreshCarts()
   cut_progress_dialog->setProgress(0);
   while(q->next()) {
     l=new RDListViewItem(cut_cart_list);
-    l->setPixmap(0,*cut_playout_map);
+    switch((RDCart::Type)q->value(4).toUInt()) {
+    case RDCart::Audio:
+      l->setPixmap(0,*cut_playout_map);
+      break;
+
+    case RDCart::All:
+    case RDCart::Macro:
+      break;
+    }
     l->setText(1,QString().sprintf("%06u",q->value(0).toUInt()));   // Number
 
     l->setText(2,q->value(1).toString());     // Title
@@ -484,7 +554,7 @@ void RDCutDialog::RefreshCuts()
     return;
   }
   sql=QString().sprintf("select DESCRIPTION,CUT_NAME from CUTS where \
-CART_NUMBER=%s",(const char *)cart_item->text(1));
+                         CART_NUMBER=%s",(const char *)cart_item->text(1));
   q=new RDSqlQuery(sql);
   while(q->next()) {
     l=new QListViewItem(cut_cut_list);
@@ -545,4 +615,61 @@ void RDCutDialog::BuildGroupList()
       }
     }
   }
+
+  //
+  // Scheduler Codes
+  //
+  cut_schedcode_box->clear();
+  cut_schedcode_box->insertItem(tr("ALL"));
+  sql="select CODE from SCHED_CODES";
+  q=new RDSqlQuery(sql);
+  while(q->next()) {
+    cut_schedcode_box->insertItem(q->value(0).toString());
+  }
+  delete q;
+
+  //
+  // Preselect Scheduler Code
+  //
+  if(cut_schedcode!=NULL) {
+    for(int i=0;i<cut_schedcode_box->count();i++) {
+      if(*cut_schedcode==cut_schedcode_box->text(i)) {
+	cut_schedcode_box->setCurrentItem(i);
+	return;
+      }
+    }
+  }
+}
+
+
+void RDCutDialog::LoadState()
+{
+  if(getenv("HOME")==NULL) {
+    return;
+  }
+  RDProfile *p=new RDProfile();
+  p->setSource(QString().sprintf("%s/.rdcartdialog",getenv("HOME")));
+  delete p;
+}
+
+
+void RDCutDialog::SaveState()
+{
+  FILE *f=NULL;
+
+  if(getenv("HOME")==NULL) {
+    return;
+  }
+  if((f=fopen(QString().sprintf("%s/.rdcartdialog",getenv("HOME")),"w"))==
+    NULL) {
+    return;
+  }
+  fprintf(f,"[RDCartDialog]\n");
+  if(cart_limit_box->isChecked()) {
+    fprintf(f,"LimitSearch=Yes\n");
+  }
+  else {
+    fprintf(f,"LimitSearch=No\n");
+  }
+  fclose(f);
 }
