@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007,2010 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdfeed.cpp,v 1.12 2010/09/08 20:37:58 cvs Exp $
+//      $Id: rdfeed.cpp,v 1.17.2.2 2013/11/13 23:36:33 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -496,7 +496,8 @@ void RDFeed::setMediaLinkMode(RDFeed::MediaLinkMode mode) const
 }
 
 
-QString RDFeed::audioUrl(RDFeed::MediaLinkMode mode,unsigned cast_id)
+QString RDFeed::audioUrl(RDFeed::MediaLinkMode mode,
+			 const QString &cgi_hostname,unsigned cast_id)
 {
   QUrl url(baseUrl());
   QString ret;
@@ -518,7 +519,7 @@ QString RDFeed::audioUrl(RDFeed::MediaLinkMode mode,unsigned cast_id)
     case RDFeed::LinkCounted:
       ret=QString().sprintf("http://%s%s/rd-bin/rdfeed.%s?%s&cast_id=%d",
 			    (const char *)basePreamble(),
-			    (const char *)url.host(),
+			    (const char *)cgi_hostname,
 			    (const char *)uploadExtension(),
 			    (const char *)keyName(),
 			    cast_id);
@@ -529,16 +530,17 @@ QString RDFeed::audioUrl(RDFeed::MediaLinkMode mode,unsigned cast_id)
 
 
 unsigned RDFeed::postCut(RDUser *user,RDStation *station,
-			 const QString &cutname,Error *err,bool log_debug)
+			 const QString &cutname,Error *err,bool log_debug,
+			 RDConfig *config)
 {
   QString tmpfile;
   QString destfile;
   QString sql;
   RDSqlQuery *q;
   RDPodcast *cast=NULL;
-  RDAudioExport::ErrorCode conv_err;
   RDUpload *upload=NULL;
   RDUpload::ErrorCode upload_err;
+  RDAudioConvert::ErrorCode audio_conv_err;
 
   emit postProgressChanged(0);
   emit postProgressChanged(1);
@@ -553,7 +555,7 @@ unsigned RDFeed::postCut(RDUser *user,RDStation *station,
     *err=RDFeed::ErrorCannotOpenFile;
     return 0;
   }
-  RDAudioExport *conv=new RDAudioExport(station,this);
+  RDAudioExport *conv=new RDAudioExport(station,config,this);
   conv->setCartNumber(cut->cartNumber());
   conv->setCutNumber(cut->cutNumber());
   conv->setDestinationFile(tmpfile);
@@ -565,7 +567,7 @@ unsigned RDFeed::postCut(RDUser *user,RDStation *station,
   settings->setBitRate(uploadBitRate());
   settings->setNormalizationLevel(normalizeLevel()/100);
   conv->setDestinationSettings(settings);
-  switch(conv->runExport(user->name(),user->password())) {
+  switch(conv->runExport(user->name(),user->password(),&audio_conv_err)) {
   case RDAudioExport::ErrorOk:
     break;
 
@@ -573,6 +575,7 @@ unsigned RDFeed::postCut(RDUser *user,RDStation *station,
     delete settings;
     delete conv;
     *err=RDFeed::ErrorUnsupportedType;
+    unlink(tmpfile);
     return 0;
 
   case RDAudioExport::ErrorNoSource:
@@ -582,9 +585,11 @@ unsigned RDFeed::postCut(RDUser *user,RDStation *station,
   case RDAudioExport::ErrorService:
   case RDAudioExport::ErrorInvalidUser:
   case RDAudioExport::ErrorAborted:
+  case RDAudioExport::ErrorConverter:
     delete settings;
     delete conv;
     *err=RDFeed::ErrorGeneral;
+    unlink(tmpfile);
     return 0;
   }
   delete settings;
@@ -617,6 +622,7 @@ unsigned RDFeed::postCut(RDUser *user,RDStation *station,
     delete upload;
     delete cast;
     *err=RDFeed::ErrorUploadFailed;
+    unlink(tmpfile);
     return 0;
   }
   emit postProgressChanged(3);
@@ -631,7 +637,7 @@ unsigned RDFeed::postCut(RDUser *user,RDStation *station,
 
 
 unsigned RDFeed::postFile(RDStation *station,const QString &srcfile,Error *err,
-			  bool log_debug)
+			  bool log_debug,RDConfig *config)
 {
   QString sql;
   RDSqlQuery *q;
@@ -639,7 +645,7 @@ unsigned RDFeed::postFile(RDStation *station,const QString &srcfile,Error *err,
   QString tmpfile;
   QString tmpfile2;
   QString destfile;
-  int time_length;
+  int time_length=0;
   RDUpload *upload=NULL;
   RDUpload::ErrorCode upload_err;
   RDWaveFile *wave=NULL;
@@ -678,16 +684,23 @@ unsigned RDFeed::postFile(RDStation *station,const QString &srcfile,Error *err,
     delete settings;
     delete conv;
     *err=RDFeed::ErrorUnsupportedType;
+    unlink(tmpfile);
     return 0;
 
   case RDAudioConvert::ErrorNoSource:
   case RDAudioConvert::ErrorNoDestination:
   case RDAudioConvert::ErrorInternal:
   case RDAudioConvert::ErrorInvalidSource:
+  case RDAudioConvert::ErrorNoDisc:
+  case RDAudioConvert::ErrorNoTrack:
+  case RDAudioConvert::ErrorInvalidSpeed:
+  case RDAudioConvert::ErrorFormatError:
+  case RDAudioConvert::ErrorNoSpace:
     emit postProgressChanged(totalPostSteps());
     delete settings;
     delete conv;
     *err=RDFeed::ErrorGeneral;
+    unlink(tmpfile);
     return 0;
   }
   delete settings;
@@ -726,6 +739,7 @@ unsigned RDFeed::postFile(RDStation *station,const QString &srcfile,Error *err,
     delete upload;
     delete cast;
     *err=RDFeed::ErrorUploadFailed;
+    unlink(tmpfile);
     return 0;
   }
   delete upload;
@@ -807,29 +821,21 @@ unsigned RDFeed::CreateCast(QString *filename,int bytes,int msecs) const
                          ITEM_CATEGORY=\"%s\",\
                          ITEM_LINK=\"%s\",\
                          SHELF_LIFE=%d,\
-                         EFFECTIVE_DATETIME=\"%s\",\
-                         ORIGIN_DATETIME=\"%s\"",
+                         EFFECTIVE_DATETIME=UTC_TIMESTAMP(),\
+                         ORIGIN_DATETIME=UTC_TIMESTAMP()",
 			feed_id,
 			(const char *)RDEscapeString(q->value(0).toString()),
 			(const char *)RDEscapeString(q->value(1).toString()),
 			(const char *)RDEscapeString(q->value(2).toString()),
 			(const char *)RDEscapeString(q->value(3).toString()),
-			q->value(4).toInt(),
-			(const char *)current_datetime.
-			toString("yyyy-MM-dd hh:mm:ss"),
-			(const char *)current_datetime.
-			toString("yyyy-MM-dd hh:mm:ss"));
+			q->value(4).toInt());
   q1=new RDSqlQuery(sql);
   delete q1;
 
   //
-  // Get the ID
+  // Get The Cast ID
   //
-  sql=QString().sprintf("select ID from PODCASTS \
-                         where (FEED_ID=%u)&&(ORIGIN_DATETIME=\"%s\")",
-			feed_id,
-			(const char *)current_datetime.
-			toString("yyyy-MM-dd hh:mm:ss"));
+  sql="select LAST_INSERT_ID() from PODCASTS";
   q1=new RDSqlQuery(sql);
   if(q1->first()) {
     cast_id=q1->value(0).toUInt();
