@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlog_event.cpp,v 1.99 2011/01/04 17:21:12 cvs Exp $
+//      $Id: rdlog_event.cpp,v 1.101.4.13 2014/01/28 17:50:26 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -30,7 +30,6 @@
 #include <rd.h>
 #include <rdescape_string.h>
 
-
 //
 // Global Classes
 //
@@ -108,7 +107,7 @@ QString RDLogEvent::serviceName() const
 }
 
 
-int RDLogEvent::load()
+int RDLogEvent::load(bool track_ptrs)
 {
   RDLogLine line;
   RDSqlQuery *q1;
@@ -120,7 +119,7 @@ int RDLogEvent::load()
   // Get the service name
   //
   sql=QString().sprintf("select SERVICE from LOGS where NAME=\"%s\"",
-			(const char *)log_name.left(log_name.length()-4));
+	     (const char *)RDEscapeString(log_name.left(log_name.length()-4)));
   q=new RDSqlQuery(sql);
   if(q->next()) {
     log_service_name=q->value(0).toString();
@@ -154,45 +153,50 @@ int RDLogEvent::load()
   // 14 - CART.YEAR
   // 15 - CART.LABEL               16 - CART.CLIENT
   // 17 - CART.AGENCY              18 - CART.USER_DEFINED
-  // 19 - CART.FORCED_LENGTH       20 - CART.CUT_QUANTITY
-  // 21 - CART.LAST_CUT_PLAYED     22 - CART.PLAY_ORDER
-  // 23 - CART.ENFORCE_LENGTH      24 - CART.PRESERVE_PITCH
-  // 25 - LOG.TYPE                 26 - LOG.COMMENT
-  // 27 - LOG.LABEL                28 - LOG.GRACE_TIME
-  // 29 - LOG.POST_POINT           30 - LOG.SOURCE
-  // 31 - LOG.EXT_START_TIME       32 - LOG.EXT_LENGTH           
-  // 33 - LOG.EXT_DATA             34 - LOG.EXT_EVENT_ID
-  // 35 - LOG.EXT_ANNC_TYPE        36 - LOG.EXT_CART_NAME
-  // 37 - CART.ASYNCRONOUS         38 - LOG.FADEUP_POINT
-  // 39 - LOG.FADEUP_GAIN          40 - LOG.FADEDOWN_POINT
-  // 41 - LOG.FADEDOWN_GAIN        42 - LOG.SEGUE_GAIN
-  // 43 - CART.PUBLISHER           44 - CART.COMPOSER
-  // 45 - CART.USAGE_CODE          46 - CART.AVERAGE_SEGUE_LENGTH
-  // 47 - LOG.LINK_EVENT_NAME      48 - LOG.LINK_START_TIME
-  // 49 - LOG.LINK_LENGTH          50 - LOG.LINK_ID
-  // 51 - LOG.LINK_EMBEDDED        52 - LOG.ORIGIN_USER
-  // 53 - LOG.ORIGIN_DATETIME      54 - CART.VALIDITY
-  // 55 - LOG.LINK_START_SLOP      56 - LOG.LINK_END_SLOP
-  // 57 - LOG.DUCK_UP_GAIN         58 - LOG.DUCK_DOWN_GAIN
-  // 59 - CART.START_DATETIME      60 - CART.END_DATETIME
+  // 19 - CART.CONDUCTOR           20 - CART.SONG_ID
+  // 21 - CART.FORCED_LENGTH       22 - CART.CUT_QUANTITY
+  // 23 - CART.LAST_CUT_PLAYED     24 - CART.PLAY_ORDER
+  // 25 - CART.ENFORCE_LENGTH      26 - CART.PRESERVE_PITCH
+  // 27 - LOG.TYPE                 28 - LOG.COMMENT
+  // 29 - LOG.LABEL                30 - LOG.GRACE_TIME
+  // 31 - LOG.POST_POINT           32 - LOG.SOURCE
+  // 33 - LOG.EXT_START_TIME       34 - LOG.EXT_LENGTH           
+  // 35 - LOG.EXT_DATA             36 - LOG.EXT_EVENT_ID
+  // 37 - LOG.EXT_ANNC_TYPE        38 - LOG.EXT_CART_NAME
+  // 39 - CART.ASYNCRONOUS         40 - LOG.FADEUP_POINT
+  // 41 - LOG.FADEUP_GAIN          42 - LOG.FADEDOWN_POINT
+  // 43 - LOG.FADEDOWN_GAIN        44 - LOG.SEGUE_GAIN
+  // 45 - CART.PUBLISHER           46 - CART.COMPOSER
+  // 47 - CART.USAGE_CODE          48 - CART.AVERAGE_SEGUE_LENGTH
+  // 49 - LOG.LINK_EVENT_NAME      50 - LOG.LINK_START_TIME
+  // 51 - LOG.LINK_LENGTH          52 - LOG.LINK_ID
+  // 53 - LOG.LINK_EMBEDDED        54 - LOG.ORIGIN_USER
+  // 55 - LOG.ORIGIN_DATETIME      56 - CART.VALIDITY
+  // 57 - LOG.LINK_START_SLOP      58 - LOG.LINK_END_SLOP
+  // 59 - LOG.DUCK_UP_GAIN         60 - LOG.DUCK_DOWN_GAIN
+  // 61 - CART.START_DATETIME      62 - CART.END_DATETIME
+  // 63 - LOG.EVENT_LENGTH         64 - CART.USE_EVENT_LENGTH
   //
-  sql=QString().sprintf("select %s.ID,%s.CART_NUMBER,\
-%s.START_TIME,%s.TIME_TYPE,%s.TRANS_TYPE,%s.START_POINT,\
-%s.END_POINT,%s.SEGUE_START_POINT,%s.SEGUE_END_POINT,\
+  sql=QString().sprintf("select `%s`.ID,`%s`.CART_NUMBER,\
+`%s`.START_TIME,`%s`.TIME_TYPE,`%s`.TRANS_TYPE,`%s`.START_POINT,\
+`%s`.END_POINT,`%s`.SEGUE_START_POINT,`%s`.SEGUE_END_POINT,\
 CART.TYPE,CART.GROUP_NAME,CART.TITLE,CART.ARTIST,CART.ALBUM,CART.YEAR,\
 CART.LABEL,CART.CLIENT,CART.AGENCY,CART.USER_DEFINED,\
+CART.CONDUCTOR,CART.SONG_ID,\
 CART.FORCED_LENGTH,CART.CUT_QUANTITY,CART.LAST_CUT_PLAYED,CART.PLAY_ORDER,\
-CART.ENFORCE_LENGTH,CART.PRESERVE_PITCH ,%s.TYPE,%s.COMMENT,\
-%s.LABEL,%s.GRACE_TIME,%s.POST_POINT,%s.SOURCE,\
-%s.EXT_START_TIME,%s.EXT_LENGTH,%s.EXT_DATA,%s.EXT_EVENT_ID,\
-%s.EXT_ANNC_TYPE,%s.EXT_CART_NAME,CART.ASYNCRONOUS,%s.FADEUP_POINT,\
-%s.FADEUP_GAIN,%s.FADEDOWN_POINT,%s.FADEDOWN_GAIN,%s.SEGUE_GAIN,\
+CART.ENFORCE_LENGTH,CART.PRESERVE_PITCH ,`%s`.TYPE,`%s`.COMMENT,\
+`%s`.LABEL,`%s`.GRACE_TIME,`%s`.POST_POINT,`%s`.SOURCE,\
+`%s`.EXT_START_TIME,`%s`.EXT_LENGTH,`%s`.EXT_DATA,`%s`.EXT_EVENT_ID,\
+`%s`.EXT_ANNC_TYPE,`%s`.EXT_CART_NAME,CART.ASYNCRONOUS,`%s`.FADEUP_POINT,\
+`%s`.FADEUP_GAIN,`%s`.FADEDOWN_POINT,`%s`.FADEDOWN_GAIN,`%s`.SEGUE_GAIN,\
 CART.PUBLISHER,CART.COMPOSER,CART.USAGE_CODE,CART.AVERAGE_SEGUE_LENGTH,\
-%s.LINK_EVENT_NAME,%s.LINK_START_TIME,%s.LINK_LENGTH,%s.LINK_ID, \
-%s.LINK_EMBEDDED,%s.ORIGIN_USER,%s.ORIGIN_DATETIME,CART.VALIDITY, \
-%s.LINK_START_SLOP,%s.LINK_END_SLOP, \
-%s.DUCK_UP_GAIN,%s.DUCK_DOWN_GAIN,CART.START_DATETIME,CART.END_DATETIME \
-from %s left join CART on %s.CART_NUMBER=CART.NUMBER order by COUNT",
+`%s`.LINK_EVENT_NAME,`%s`.LINK_START_TIME,`%s`.LINK_LENGTH,`%s`.LINK_ID, \
+`%s`.LINK_EMBEDDED,`%s`.ORIGIN_USER,`%s`.ORIGIN_DATETIME,CART.VALIDITY, \
+`%s`.LINK_START_SLOP,`%s`.LINK_END_SLOP, \
+`%s`.DUCK_UP_GAIN,`%s`.DUCK_DOWN_GAIN,CART.START_DATETIME,CART.END_DATETIME,\
+`%s`.EVENT_LENGTH,CART.USE_EVENT_LENGTH \
+from `%s` left join CART on `%s`.CART_NUMBER=CART.NUMBER order by COUNT",
+				(const char *)log_name,
 				(const char *)log_name,
 				(const char *)log_name,
 				(const char *)log_name,
@@ -240,7 +244,7 @@ from %s left join CART on %s.CART_NUMBER=CART.NUMBER order by COUNT",
   for(int i=0;i<q->size();i++) {
     line.clear();
     q->next();
-    line.setType((RDLogLine::Type)q->value(25).toInt());       // Type
+    line.setType((RDLogLine::Type)q->value(27).toInt());       // Type
     line.setId(q->value(0).toInt());                           // Log Line ID
     if(q->value(0).toInt()>log_max_id) {
       log_max_id=q->value(0).toInt();
@@ -252,176 +256,178 @@ from %s left join CART on %s.CART_NUMBER=CART.NUMBER order by COUNT",
     line.
       setTimeType((RDLogLine::TimeType)q->value(3).toInt());   // Time Type
     if((line.timeType()==RDLogLine::Hard)&&
-       (q->value(29).toString()==QString("Y"))) {              // Post Point
+       (q->value(31).toString()==QString("Y"))) {              // Post Point
     }
     line.
       setTransType((RDLogLine::TransType)q->value(4).toInt()); // Trans Type
-    line.setMarkerComment(q->value(26).toString());         // Comment
-    line.setMarkerLabel(q->value(27).toString());           // Label
-    line.setGraceTime(q->value(28).toInt());                // Grace Time
-    line.setSource((RDLogLine::Source)q->value(30).toUInt());
-    line.setLinkEventName(q->value(47).toString());         // Link Event Name
-    line.setLinkStartTime(QTime().addMSecs(q->value(48).toInt()));   // Link Start Time
-    line.setLinkLength(q->value(49).toInt());               // Link Length
-    line.setLinkStartSlop(q->value(55).toInt());            // Link Start Slop
-    line.setLinkEndSlop(q->value(56).toInt());              // Link End Slop
-    line.setLinkId(q->value(50).toInt());                   // Link ID
-    line.setLinkEmbedded(RDBool(q->value(51).toString()));   // Link Embedded
-    line.setOriginUser(q->value(52).toString());            // Origin User
-    line.setOriginDateTime(q->value(53).toDateTime());      // Origin DateTime
+    line.setMarkerComment(q->value(28).toString());         // Comment
+    line.setMarkerLabel(q->value(29).toString());           // Label
+    line.setGraceTime(q->value(30).toInt());                // Grace Time
+    line.setUseEventLength(RDBool(q->value(64).toString())); // Use Event Length
+    line.setEventLength(q->value(63).toInt());              // Event Length
+    line.setSource((RDLogLine::Source)q->value(32).toUInt());
+    line.setLinkEventName(q->value(49).toString());         // Link Event Name
+    line.setLinkStartTime(QTime().addMSecs(q->value(50).toInt()));   // Link Start Time
+    line.setLinkLength(q->value(51).toInt());               // Link Length
+    line.setLinkStartSlop(q->value(57).toInt());            // Link Start Slop
+    line.setLinkEndSlop(q->value(58).toInt());              // Link End Slop
+    line.setLinkId(q->value(52).toInt());                   // Link ID
+    line.setLinkEmbedded(RDBool(q->value(53).toString()));   // Link Embedded
+    line.setOriginUser(q->value(54).toString());            // Origin User
+    line.setOriginDateTime(q->value(55).toDateTime());      // Origin DateTime
     switch(line.type()) {
-	case RDLogLine::Cart:
-	  line.setCartNumber(q->value(1).toUInt());          // Cart Number
-	  line.setStartPoint(q->value(5).toInt(),RDLogLine::LogPointer);
-	  line.setEndPoint(q->value(6).toInt(),RDLogLine::LogPointer);
-	  line.setSegueStartPoint(q->value(7).toInt(),RDLogLine::LogPointer);
-	  line.setSegueEndPoint(q->value(8).toInt(),RDLogLine::LogPointer);
-	  line.
-	    setCartType((RDCart::Type)q->value(9).toInt());  // Cart Type
-	  line.setGroupName(q->value(10).toString());       // Group Name
-	  line.setGroupColor(group_colors[q->value(10).toString()]);
-	  line.setTitle(q->value(11).toString());           // Title
-	  line.setArtist(q->value(12).toString());          // Artist
-	  line.setPublisher(q->value(43).toString());       // Publisher
-	  line.setComposer(q->value(44).toString());        // Composer
-	  line.setAlbum(q->value(13).toString());           // Album
-	  line.setYear(q->value(14).toDate());              // Year
-	  line.setLabel(q->value(15).toString());           // Label
-	  line.setClient(q->value(16).toString());          // Client
-	  line.setAgency(q->value(17).toString());          // Agency
-	  line.setUserDefined(q->value(18).toString());     // User Defined
-	  line.setUsageCode((RDCart::UsageCode)q->value(45).toInt());
-	  line.setForcedLength(q->value(19).toUInt());      // Forced Length
-	  if((q->value(7).toInt()<0)||(q->value(8).toInt()<0)) {
-	    line.setAverageSegueLength(q->value(46).toInt());
-	  }
-	  else {
-	    line.
-	      setAverageSegueLength(q->value(7).toInt()-q->value(5).toInt());
-	  }
-	  line.setCutQuantity(q->value(20).toUInt());       // Cut Quantity
-	  line.setLastCutPlayed(q->value(21).toUInt());     // Last Cut Played
-	  line.
-	    setPlayOrder((RDCart::PlayOrder)q->value(22).toUInt()); // Play Ord
-	  line.
-	    setEnforceLength(RDBool(q->value(23).toString())); // Enforce Length
-	  line.
-	    setPreservePitch(RDBool(q->value(24).toString())); // Preserve Pitch
-	  if(!q->value(31).isNull()) {                      // Ext Start Time
-	    line.setExtStartTime(q->value(31).toTime());
-	  }
-	  if(!q->value(32).isNull()) {                      // Ext Length
-	    line.setExtLength(q->value(32).toInt());
-	  }
-	  if(!q->value(33).isNull()) {                      // Ext Data
-	    line.setExtData(q->value(33).toString());
-	  }
-	  if(!q->value(34).isNull()) {                      // Ext Event ID
-	    line.setExtEventId(q->value(34).toString());
-	  }
-	  if(!q->value(35).isNull()) {                      // Ext Annc. Type
-	    line.setExtAnncType(q->value(35).toString());
-	  }
-	  if(!q->value(36).isNull()) {                      // Ext Cart Name
-	    line.setExtCartName(q->value(36).toString());
-	  }
-	  if(!q->value(38).isNull()) {                      // FadeUp Point
-	    line.setFadeupPoint(q->value(38).toInt(),RDLogLine::LogPointer);
-	  }
-	  if(!q->value(39).isNull()) {                      // FadeUp Gain
-	    line.setFadeupGain(q->value(39).toInt());
-	  }
-	  if(!q->value(40).isNull()) {                      // FadeDown Point
-	    line.setFadedownPoint(q->value(40).toInt(),RDLogLine::LogPointer);
-	  }
-	  if(!q->value(41).isNull()) {                      // FadeDown Gain
-	    line.setFadedownGain(q->value(41).toInt());
-	  }
-	  if(!q->value(42).isNull()) {                      // Segue Gain
-	    line.setSegueGain(q->value(42).toInt());
-	  }
-	  if(!q->value(57).isNull()) {                      // Duck Up Gain
-	    line.setDuckUpGain(q->value(57).toInt());
-	  }
-	  if(!q->value(58).isNull()) {                      // Duck Down Gain
-	    line.setDuckDownGain(q->value(58).toInt());
-	  }
-	  if(!q->value(59).isNull()) {                      // Start Datetime
-	    line.setStartDatetime(q->value(59).toDateTime());
-	  }
-	  if(!q->value(60).isNull()) {                      // End Datetime
-	    line.setEndDatetime(q->value(60).toDateTime());
-	  }
-	  line.setValidity((RDCart::Validity)q->value(54).toInt()); // Validity
-	  break;
+    case RDLogLine::Cart:
+      line.setCartNumber(q->value(1).toUInt());          // Cart Number
+      line.setStartPoint(q->value(5).toInt(),RDLogLine::LogPointer);
+      line.setEndPoint(q->value(6).toInt(),RDLogLine::LogPointer);
+      line.setSegueStartPoint(q->value(7).toInt(),RDLogLine::LogPointer);
+      line.setSegueEndPoint(q->value(8).toInt(),RDLogLine::LogPointer);
+      line.setCartType((RDCart::Type)q->value(9).toInt());  // Cart Type
+      line.setGroupName(q->value(10).toString());       // Group Name
+      line.setGroupColor(group_colors[q->value(10).toString()]);
+      line.setTitle(q->value(11).toString());           // Title
+      line.setArtist(q->value(12).toString());          // Artist
+      line.setPublisher(q->value(45).toString());       // Publisher
+      line.setComposer(q->value(46).toString());        // Composer
+      line.setAlbum(q->value(13).toString());           // Album
+      line.setYear(q->value(14).toDate());              // Year
+      line.setLabel(q->value(15).toString());           // Label
+      line.setClient(q->value(16).toString());          // Client
+      line.setAgency(q->value(17).toString());          // Agency
+      line.setUserDefined(q->value(18).toString());     // User Defined
+      line.setConductor(q->value(19).toString());       // Conductor
+      line.setSongId(q->value(20).toString());          // Song ID
+      line.setUsageCode((RDCart::UsageCode)q->value(47).toInt());
+      line.setForcedLength(q->value(21).toUInt());      // Forced Length
+      if((q->value(7).toInt()<0)||(q->value(8).toInt()<0)) {
+	line.setAverageSegueLength(q->value(48).toInt());
+      }
+      else {
+	line.
+	  setAverageSegueLength(q->value(7).toInt()-q->value(5).toInt());
+      }
+      line.setCutQuantity(q->value(22).toUInt());       // Cut Quantity
+      line.setLastCutPlayed(q->value(23).toUInt());     // Last Cut Played
+      line.
+	setPlayOrder((RDCart::PlayOrder)q->value(24).toUInt()); // Play Ord
+      line.
+	setEnforceLength(RDBool(q->value(25).toString())); // Enforce Length
+      line.
+	setPreservePitch(RDBool(q->value(26).toString())); // Preserve Pitch
+      if(!q->value(33).isNull()) {                      // Ext Start Time
+	line.setExtStartTime(q->value(33).toTime());
+      }
+      if(!q->value(34).isNull()) {                      // Ext Length
+	line.setExtLength(q->value(34).toInt());
+      }
+      if(!q->value(35).isNull()) {                      // Ext Data
+	line.setExtData(q->value(35).toString());
+      }
+      if(!q->value(36).isNull()) {                      // Ext Event ID
+	line.setExtEventId(q->value(36).toString());
+      }
+      if(!q->value(37).isNull()) {                      // Ext Annc. Type
+	line.setExtAnncType(q->value(37).toString());
+      }
+      if(!q->value(38).isNull()) {                      // Ext Cart Name
+	line.setExtCartName(q->value(38).toString());
+      }
+      if(!q->value(40).isNull()) {                      // FadeUp Point
+	line.setFadeupPoint(q->value(40).toInt(),RDLogLine::LogPointer);
+      }
+      if(!q->value(41).isNull()) {                      // FadeUp Gain
+	line.setFadeupGain(q->value(41).toInt());
+      }
+      if(!q->value(42).isNull()) {                      // FadeDown Point
+	line.setFadedownPoint(q->value(42).toInt(),RDLogLine::LogPointer);
+      }
+      if(!q->value(43).isNull()) {                      // FadeDown Gain
+	line.setFadedownGain(q->value(43).toInt());
+      }
+      if(!q->value(44).isNull()) {                      // Segue Gain
+	line.setSegueGain(q->value(44).toInt());
+      }
+      if(!q->value(59).isNull()) {                      // Duck Up Gain
+	line.setDuckUpGain(q->value(59).toInt());
+      }
+      if(!q->value(60).isNull()) {                      // Duck Down Gain
+	line.setDuckDownGain(q->value(60).toInt());
+      }
+      if(!q->value(61).isNull()) {                      // Start Datetime
+	line.setStartDatetime(q->value(61).toDateTime());
+      }
+      if(!q->value(62).isNull()) {                      // End Datetime
+	line.setEndDatetime(q->value(62).toDateTime());
+      }
+      line.setValidity((RDCart::Validity)q->value(56).toInt()); // Validity
+      break;
 
-	case RDLogLine::Macro:
-	  line.setCartNumber(q->value(1).toUInt());          // Cart Number
-	  line.
-	    setCartType((RDCart::Type)q->value(9).toInt());  // Cart Type
-	  line.setGroupName(q->value(10).toString());       // Group Name
-	  line.setGroupColor(group_colors[q->value(10).toString()]);
-	  line.setTitle(q->value(11).toString());           // Title
-	  line.setArtist(q->value(12).toString());          // Artist
-	  line.setPublisher(q->value(43).toString());       // Publisher
-	  line.setComposer(q->value(44).toString());        // Composer
-	  line.setAlbum(q->value(13).toString());           // Album
-	  line.setYear(q->value(14).toDate());              // Year
-	  line.setLabel(q->value(15).toString());           // Label
-	  line.setClient(q->value(16).toString());          // Client
-	  line.setAgency(q->value(17).toString());          // Agency
-	  line.setUserDefined(q->value(18).toString());     // User Defined
-	  line.setForcedLength(q->value(19).toUInt());      // Forced Length
-	  line.setAverageSegueLength(q->value(19).toInt());
-	  if(!q->value(31).isNull()) {                      // Ext Start Time
-	    line.setExtStartTime(q->value(31).toTime());
-	  }
-	  if(!q->value(32).isNull()) {                      // Ext Length
-	    line.setExtLength(q->value(32).toInt());
-	  }
-	  if(!q->value(33).isNull()) {                      // Ext Data
-	    line.setExtData(q->value(33).toString());
-	  }
-	  if(!q->value(34).isNull()) {                      // Ext Event ID
-	    line.setExtEventId(q->value(34).toString());
-	  }
-	  if(!q->value(35).isNull()) {                      // Ext Annc. Type
-	    line.setExtAnncType(q->value(35).toString());
-	  }
-	  if(!q->value(36).isNull()) {                      // Ext Cart Name
-	    line.setExtCartName(q->value(36).toString());
-	  }
-	  if(!q->value(37).isNull()) {                      // Asyncronous
-	    line.setAsyncronous(RDBool(q->value(37).toString()));
-	  }
-	  break;
+    case RDLogLine::Macro:
+      line.setCartNumber(q->value(1).toUInt());          // Cart Number
+      line.setCartType((RDCart::Type)q->value(9).toInt());  // Cart Type
+      line.setGroupName(q->value(10).toString());       // Group Name
+      line.setGroupColor(group_colors[q->value(10).toString()]);
+      line.setTitle(q->value(11).toString());           // Title
+      line.setArtist(q->value(12).toString());          // Artist
+      line.setPublisher(q->value(45).toString());       // Publisher
+      line.setComposer(q->value(46).toString());        // Composer
+      line.setAlbum(q->value(13).toString());           // Album
+      line.setYear(q->value(14).toDate());              // Year
+      line.setLabel(q->value(15).toString());           // Label
+      line.setClient(q->value(16).toString());          // Client
+      line.setAgency(q->value(17).toString());          // Agency
+      line.setUserDefined(q->value(18).toString());     // User Defined
+      line.setForcedLength(q->value(21).toUInt());      // Forced Length
+      line.setAverageSegueLength(q->value(21).toInt());
+      if(!q->value(33).isNull()) {                      // Ext Start Time
+	line.setExtStartTime(q->value(33).toTime());
+      }
+      if(!q->value(34).isNull()) {                      // Ext Length
+	line.setExtLength(q->value(34).toInt());
+      }
+      if(!q->value(35).isNull()) {                      // Ext Data
+	line.setExtData(q->value(35).toString());
+      }
+      if(!q->value(36).isNull()) {                      // Ext Event ID
+	line.setExtEventId(q->value(36).toString());
+      }
+      if(!q->value(37).isNull()) {                      // Ext Annc. Type
+	line.setExtAnncType(q->value(37).toString());
+      }
+      if(!q->value(38).isNull()) {                      // Ext Cart Name
+	line.setExtCartName(q->value(38).toString());
+      }
+      if(!q->value(39).isNull()) {                      // Asyncronous
+	line.setAsyncronous(RDBool(q->value(39).toString()));
+      }
+      break;
 
-	case RDLogLine::Marker:
-	  break;
+    case RDLogLine::Marker:
+      break;
 
-	case RDLogLine::Track:
-	  break;
+    case RDLogLine::Track:
+      break;
 
-	case RDLogLine::Chain:
-	  sql=
-	    QString().sprintf("select DESCRIPTION from LOGS where NAME=\"%s\"",
-			      (const char *)line.markerLabel());
-	  q1=new RDSqlQuery(sql);
-	  if(q1->first()) {
-	    line.setMarkerComment(q1->value(0).toString());
-	  }
-	  delete q1;
-	  break;
+    case RDLogLine::Chain:
+      sql=
+	QString().sprintf("select DESCRIPTION from LOGS where NAME=\"%s\"",
+			  (const char *)line.markerLabel());
+      q1=new RDSqlQuery(sql);
+      if(q1->first()) {
+	line.setMarkerComment(q1->value(0).toString());
+      }
+      delete q1;
+      break;
 
-	default:
-	  break;
+    default:
+      break;
     }
 
     line.setHasCustomTransition(prev_custom||(q->value(5).toInt()>=0)||\
-				(q->value(38).toInt()>=0));
+				(q->value(40).toInt()>=0));
     if(line.type()==RDLogLine::Cart) {
       prev_custom=(q->value(6).toInt()>=0)||(q->value(7).toInt()>=0)||
-	(q->value(8).toInt()>=0)||(q->value(40).toInt()>=0);
+	(q->value(8).toInt()>=0)||(q->value(42).toInt()>=0);
     }
     else {
       prev_custom=false;
@@ -443,6 +449,43 @@ from %s left join CART on %s.CART_NUMBER=CART.NUMBER order by COUNT",
 
   LoadNowNext();
 
+  if(track_ptrs) {
+    //
+    // Load default cart pointers for "representative" cuts.  This is
+    // really only useful when setting up a voice tracker.
+    //
+    for(int i=0;i<size();i++) {
+      RDLogLine *ll=logLine(i);
+      if(ll->cartType()==RDCart::Audio) {
+	sql=QString("select START_POINT,END_POINT,")+
+	  "SEGUE_START_POINT,SEGUE_END_POINT,"+
+	  "TALK_START_POINT,TALK_END_POINT,"
+	  "HOOK_START_POINT,HOOK_END_POINT,"+
+	  "FADEUP_POINT,FADEDOWN_POINT,CUT_NAME,"+
+	  "ORIGIN_NAME,ORIGIN_DATETIME from CUTS "+
+	  QString().sprintf("where CART_NUMBER=%u ",ll->cartNumber())+
+	  "order by CUT_NAME";
+	q=new RDSqlQuery(sql);
+	if(q->first()) {
+	  ll->setStartPoint(q->value(0).toInt(),RDLogLine::CartPointer);
+	  ll->setEndPoint(q->value(1).toInt(),RDLogLine::CartPointer);
+	  ll->setSegueStartPoint(q->value(2).toInt(),RDLogLine::CartPointer);
+	  ll->setSegueEndPoint(q->value(3).toInt(),RDLogLine::CartPointer);
+	  ll->setTalkStartPoint(q->value(4).toInt());
+	  ll->setTalkEndPoint(q->value(5).toInt());
+	  ll->setHookStartPoint(q->value(6).toInt());
+	  ll->setHookEndPoint(q->value(7).toInt());
+	  ll->setFadeupPoint(q->value(8).toInt(),RDLogLine::CartPointer);
+	  ll->setFadedownPoint(q->value(9).toInt(),RDLogLine::CartPointer);
+	  ll->setCutNumber(RDCut::cutNumber(q->value(10).toString()));
+	  ll->setOriginUser(q->value(11).toString());
+	  ll->setOriginDateTime(q->value(12).toDateTime());
+	}
+	delete q;
+      }
+    }
+  }
+
   return log_line.size();
 }
 
@@ -457,7 +500,7 @@ void RDLogEvent::save(bool update_tracks,int line)
   }
   if(line<0) {
     if(exists()) {
-      sql=QString().sprintf("drop table %s",(const char *)log_name);
+      sql=QString().sprintf("drop table `%s`",(const char *)log_name);
       q=new RDSqlQuery(sql);
       delete q;
     }
@@ -467,7 +510,7 @@ void RDLogEvent::save(bool update_tracks,int line)
     }
   }
   else {
-    sql=QString().sprintf("delete from %s where COUNT=%d",
+    sql=QString().sprintf("delete from `%s` where COUNT=%d",
 			  (const char *)log_name,line);
     q=new RDSqlQuery(sql);
     delete q;
@@ -519,7 +562,7 @@ int RDLogEvent::validate(QString *report,const QDate &date)
   //
   for(int i=0;i<size();i++) {
     if(logLine(i)->cartNumber()>0) {
-      sql=QString().sprintf("select TYPE from CART where NUMBER=%d",
+      sql=QString().sprintf("select TYPE,TITLE from CART where NUMBER=%d",
 			    logLine(i)->cartNumber());
       q=new RDSqlQuery(sql);
       if(!q->first()) {
@@ -574,9 +617,10 @@ int RDLogEvent::validate(QString *report,const QDate &date)
 	  q1=new RDSqlQuery(sql);
 	  if(!q1->first()) {
 	    *report+=QString().
-	      sprintf(" %s - cart %06d is not playable\n",
+	      sprintf(" %s - cart %06d [%s] is not playable\n",
 		      (const char *)logLine(i)->startTime(RDLogLine::Logged).
-		      toString("hh:mm:ss"),logLine(i)->cartNumber());
+		      toString("hh:mm:ss"),logLine(i)->cartNumber(),
+		      (const char *)q->value(1).toString());
 	    errs++;
 	  }
 	  delete q1;
@@ -658,7 +702,6 @@ void RDLogEvent::refresh(int line)
     log_line[line]->setValidity(RDCart::NeverValid);
   }
   delete q;
-  return;
 }
 
 
@@ -682,10 +725,9 @@ void RDLogEvent::insert(int line,int num_lines,bool preserve_trans)
     }
   }
   if(line<size()) {
-    std::vector<RDLogLine *>::iterator it=log_line.begin()+line;
-    log_line.insert(it,num_lines,new RDLogLine());
-    for(int i=line;i<(line+num_lines);i++) {
-      log_line[i]->setId(++log_max_id);
+    for(int i=0;i<num_lines;i++) {
+      log_line.insert(log_line.begin()+line+i,1,new RDLogLine());
+      log_line[line+i]->setId(++log_max_id);
     }
     return;
   }
@@ -785,7 +827,13 @@ int RDLogEvent::length(int from_line,int to_line,QTime *sched_time)
   }
   int len=0;
   for(int i=from_line;i<to_line;i++) {
-    len+=logLine(i)->forcedLength();
+    if(((i+1)>=size())||(logLine(i+1)->transType()!=RDLogLine::Segue)||
+       (logLine(i)->segueStartPoint()<0)) {
+      len+=logLine(i)->forcedLength();
+    }
+    else {
+      len+=logLine(i)->segueStartPoint()-logLine(i)->startPoint();
+    }
   }
 
   return len;
@@ -909,7 +957,7 @@ QTime RDLogEvent::blockStartTime(int line)
 }
 
 
-RDLogLine *RDLogEvent::logLine(int line)
+RDLogLine *RDLogEvent::logLine(int line) const
 {
   if((line<0)||((unsigned)line>=log_line.size())) {
     return NULL;
@@ -918,7 +966,15 @@ RDLogLine *RDLogEvent::logLine(int line)
 }
 
 
-RDLogLine *RDLogEvent::loglineById(int id)
+void RDLogEvent::setLogLine(int line,RDLogLine *ll)
+{
+  int id=log_line[line]->id();
+  *log_line[line]=*ll;
+  log_line[line]->setId(id);
+}
+
+
+RDLogLine *RDLogEvent::loglineById(int id) const
 {
   for(int i=0;i<size();i++) {
     if(log_line[i]->id()==id) {
@@ -940,6 +996,31 @@ int RDLogEvent::lineById(int id) const
 }
 
 
+int RDLogEvent::lineByStartHour(int hour,RDLogLine::StartTimeType type) const
+{
+  for(int i=0;i<size();i++) {
+    if(!log_line[i]->startTime(type).isNull()&&
+       (log_line[i]->startTime(type).hour()==hour)) {
+      return i;
+    }
+  }
+  return -1;
+}
+
+
+int RDLogEvent::lineByStartHour(int hour) const
+{
+  int line=-1;
+
+  if((line=lineByStartHour(hour,RDLogLine::Initial))<0) {
+    if((line=lineByStartHour(hour,RDLogLine::Predicted))<0) {
+      line=lineByStartHour(hour,RDLogLine::Imported);
+    }
+  }
+  return line;
+}
+
+
 int RDLogEvent::nextTimeStart(QTime after)
 {
   for(unsigned i=0;i<log_line.size();i++) {
@@ -1021,11 +1102,25 @@ int RDLogEvent::nextLinkId() const
 }
 
 
+QString RDLogEvent::xml() const
+{
+  QString ret;
+
+  ret+="<logList>\n";
+  for(int i=0;i<size();i++) {
+    ret+=logLine(i)->xml(i);
+  }
+  ret+="</logList>\n";
+
+  return ret;
+}
+
+
 void RDLogEvent::SaveLine(int line)
 {
   QString sql;
   RDSqlQuery *q;
-  sql=QString().sprintf("insert into %s set ID=%d,COUNT=%d,\
+  sql=QString().sprintf("insert into `%s` set ID=%d,COUNT=%d,\
                          CART_NUMBER=%u,START_TIME=%d,TIME_TYPE=%d,\
                          TRANS_TYPE=%d,START_POINT=%d,END_POINT=%d,\
                          SEGUE_START_POINT=%d,SEGUE_END_POINT=%d,TYPE=%d,\
@@ -1039,7 +1134,8 @@ void RDLogEvent::SaveLine(int line)
                          LINK_LENGTH=%d,LINK_ID=%d,LINK_EMBEDDED=\"%s\",\
                          ORIGIN_USER=\"%s\",ORIGIN_DATETIME=\"%s\",\
                          LINK_START_SLOP=%d,LINK_END_SLOP=%d,\
-                         DUCK_UP_GAIN=%d,DUCK_DOWN_GAIN=%d",
+                         DUCK_UP_GAIN=%d,DUCK_DOWN_GAIN=%d,\
+                         EVENT_LENGTH=%d",
 			(const char *)log_name,
 			log_line[line]->id(),
 			line,
@@ -1087,7 +1183,8 @@ void RDLogEvent::SaveLine(int line)
 			log_line[line]->linkStartSlop(),
 			log_line[line]->linkEndSlop(),
                         log_line[line]->duckUpGain(),
-                        log_line[line]->duckDownGain());
+                        log_line[line]->duckDownGain(),
+			log_line[line]->eventLength());
 
   // printf("SQL: %s\n",(const char *)sql);
   q=new RDSqlQuery(sql);
