@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlogedit_conf.cpp,v 1.9 2007/09/14 14:06:24 fredg Exp $
+//      $Id: rdlogedit_conf.cpp,v 1.12.8.1 2014/01/08 18:14:34 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -19,10 +19,10 @@
 //   License along with this program; if not, write to the Free Software
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-
+#include <rddb.h>
 #include <rdconf.h>
 #include <rdlogedit_conf.h>
-
+#include <rdescape_string.h>
 
 //
 // Global Classes
@@ -30,18 +30,18 @@
 RDLogeditConf::RDLogeditConf(const QString &station)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   
   lib_station=station;
 
   sql=QString().sprintf("select ID from RDLOGEDIT where STATION=\"%s\"",
-			(const char *)lib_station);
-  q=new QSqlQuery(sql);
+			(const char *)RDEscapeString(lib_station));
+  q=new RDSqlQuery(sql);
   if(!q->first()) {
     delete q;
     sql=QString().sprintf("insert into RDLOGEDIT set STATION=\"%s\"",
-			  (const char *)lib_station);
-    q=new QSqlQuery(sql);
+			  (const char *)RDEscapeString(lib_station));
+    q=new RDSqlQuery(sql);
   }
   delete q;
 }
@@ -113,18 +113,6 @@ void RDLogeditConf::setFormat(unsigned format) const
 }
 
 
-unsigned RDLogeditConf::sampleRate() const
-{
-  return RDGetSqlValue("RDLOGEDIT","STATION",lib_station,"SAMPRATE").toUInt();
-}
-
-
-void RDLogeditConf::setSampleRate(unsigned rate) const
-{
-  SetRow("SAMPRATE",rate);
-}
-
-
 unsigned RDLogeditConf::layer() const
 {
   return RDGetSqlValue("RDLOGEDIT","STATION",lib_station,"LAYER").toUInt();
@@ -149,6 +137,19 @@ void RDLogeditConf::setBitrate(unsigned rate) const
 }
 
 
+bool RDLogeditConf::enableSecondStart() const
+{
+  return RDBool(RDGetSqlValue("RDLOGEDIT","STATION",lib_station,
+			      "ENABLE_SECOND_START").toString());
+}
+  
+
+void RDLogeditConf::setEnableSecondStart(bool state) const
+{
+  SetRow("ENABLE_SECOND_START",state);
+}
+
+
 unsigned RDLogeditConf::defaultChannels() const
 {
   return RDGetSqlValue("RDLOGEDIT","STATION",lib_station,"DEFAULT_CHANNELS").toUInt();
@@ -279,14 +280,14 @@ void RDLogeditConf::setDefaultTransType(RDLogLine::TransType type)
 void RDLogeditConf::getSettings(RDSettings *s) const
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   sql=QString().sprintf("select DEFAULT_CHANNELS,SAMPRATE,\
                          FORMAT,BITRATE,RIPPER_LEVEL,\
                          TRIM_THRESHOLD from RDLOGEDIT \
                          where STATION=\"%s\"",
-			(const char *)lib_station);
-  q=new QSqlQuery(sql);
+			(const char *)RDEscapeString(lib_station));
+  q=new RDSqlQuery(sql);
   s->clear();
   if(q->first()) {
     s->setChannels(q->value(0).toUInt());
@@ -311,27 +312,41 @@ void RDLogeditConf::getSettings(RDSettings *s) const
 
 void RDLogeditConf::SetRow(const QString &param,int value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("UPDATE RDLOGEDIT SET %s=%d WHERE STATION=\"%s\"",
 			(const char *)param,
 			value,
-			(const char *)lib_station);
-  q=new QSqlQuery(sql);
+			(const char *)RDEscapeString(lib_station));
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
 
 void RDLogeditConf::SetRow(const QString &param,unsigned value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("UPDATE RDLOGEDIT SET %s=%d WHERE STATION=\"%s\"",
 			(const char *)param,
 			value,
-			(const char *)lib_station);
-  q=new QSqlQuery(sql);
+			(const char *)RDEscapeString(lib_station));
+  q=new RDSqlQuery(sql);
+  delete q;
+}
+
+
+void RDLogeditConf::SetRow(const QString &param,bool value) const
+{
+  RDSqlQuery *q;
+  QString sql;
+
+  sql=QString().sprintf("update RDLOGEDIT set %s=\"%s\" where STATION=\"%s\"",
+			(const char *)param,
+			(const char *)RDYesNo(value),
+			(const char *)RDEscapeString(lib_station));
+  q=new RDSqlQuery(sql);
   delete q;
 }
