@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_logs.cpp,v 1.15 2007/02/19 16:57:07 fredg Exp $
+//      $Id: list_logs.cpp,v 1.22.6.1 2012/08/10 19:07:21 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,12 +23,11 @@
 #include <qpushbutton.h>
 
 #include <rdadd_log.h>
-
+#include <rddb.h>
 #include <list_logs.h>
 #include <globals.h>
 
-ListLogs::ListLogs(QString *logname,QString *svcname,LogPlay *log,
-		   QWidget *parent,const char *name)
+ListLogs::ListLogs(LogPlay *log,QWidget *parent,const char *name)
   : QDialog(parent,name,true)
 {
   //
@@ -45,8 +44,6 @@ ListLogs::ListLogs(QString *logname,QString *svcname,LogPlay *log,
   QFont button_font("Helvetica",12,QFont::Bold);
   button_font.setPixelSize(12);
 
-  list_logname=logname;
-  list_svcname=svcname;
   list_log=log;
   setCaption(tr("Select a Log"));
 
@@ -55,13 +52,13 @@ ListLogs::ListLogs(QString *logname,QString *svcname,LogPlay *log,
   //
   list_log_list=new QListView(this,"list_log_list");
   list_log_list->setGeometry(10,10,
-			    sizeHint().width()-20,sizeHint().height()-80);
+                            sizeHint().width()-20,sizeHint().height()-80);
   list_log_list->setAllColumnsShowFocus(true);
   list_log_list->setItemMargin(5);
   connect(list_log_list,
-	  SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),
-	  this,
-	  SLOT(doubleClickedData(QListViewItem *,const QPoint &,int)));
+          SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),
+          this,
+          SLOT(doubleClickedData(QListViewItem *,const QPoint &,int)));
   list_log_list->addColumn(tr("NAME"));
   list_log_list->setColumnAlignment(0,Qt::AlignLeft);
   list_log_list->addColumn(tr("DESCRIPTION"));
@@ -99,11 +96,11 @@ ListLogs::ListLogs(QString *logname,QString *svcname,LogPlay *log,
   //
   // Save As Button
   //
-  QPushButton *saveas_button=new QPushButton(this,"saveas_button");
-  saveas_button->setGeometry(300,sizeHint().height()-60,80,50);
-  saveas_button->setFont(button_font);
-  saveas_button->setText(tr("Save &As"));
-  connect(saveas_button,SIGNAL(clicked()),this,SLOT(saveAsButtonData()));
+  list_saveas_button=new QPushButton(this,"list_saveas_button");
+  list_saveas_button->setGeometry(300,sizeHint().height()-60,80,50);
+  list_saveas_button->setFont(button_font);
+  list_saveas_button->setText(tr("Save &As"));
+  connect(list_saveas_button,SIGNAL(clicked()),this,SLOT(saveAsButtonData()));
 
   //
   // Cancel Button
@@ -116,11 +113,6 @@ ListLogs::ListLogs(QString *logname,QString *svcname,LogPlay *log,
   connect(button,SIGNAL(clicked()),this,SLOT(cancelButtonData()));
 
   RefreshList();
-
-  //
-  // Set Control Perms
-  //
-  saveas_button->setEnabled(rduser->createLog());
 }
 
 
@@ -136,6 +128,16 @@ QSizePolicy ListLogs::sizePolicy() const
 }
 
 
+int ListLogs::exec(QString *logname,QString *svcname)
+{
+  list_logname=logname;
+  list_svcname=svcname;
+  list_saveas_button->setEnabled(rduser->createLog());
+  RefreshList();
+  return QDialog::exec();
+}
+
+
 void ListLogs::closeEvent(QCloseEvent *e)
 {
   done(1);
@@ -174,8 +176,15 @@ void ListLogs::saveAsButtonData()
 {
   QString logname;
   QString svcname=*list_svcname;
-  RDAddLog *log=new RDAddLog(&logname,&svcname,rdstation_conf,
-			     tr("Rename Log"),this,"log");
+  RDAddLog *log;
+  if (rdstation_conf->broadcastSecurity() == RDStation::UserSec) {
+    log=new RDAddLog(&logname,&svcname,rdstation_conf,
+                     tr("Rename Log"),this,"log", rduser);
+  } else { // RDStation::HostSec
+    log=new RDAddLog(&logname,&svcname,rdstation_conf,
+                     tr("Rename Log"),this,"log");
+  }
+
   if(log->exec()<0) {
     delete log;
     return;
@@ -201,34 +210,48 @@ void ListLogs::cancelButtonData()
 
 void ListLogs::RefreshList()
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
   QListViewItem *l;
   QDate current_date=QDate::currentDate();
+  QStringList services_list;
 
   list_log_list->clear();
-  sql=QString().sprintf("select SERVICE_NAME from SERVICE_PERMS \
-                         where STATION_NAME=\"%s\"",
-			(const char *)rdstation_conf->name());
-  q=new QSqlQuery(sql);
-  if(q->size()==0) {
+
+  if (rdstation_conf->broadcastSecurity() == RDStation::UserSec) {
+    if(rduser!=NULL) {
+      services_list = rduser->services();
+    }
+  } 
+  else { // RDStation::HostSec
+    sql=QString().sprintf("select SERVICE_NAME from SERVICE_PERMS \
+                           where STATION_NAME=\"%s\"",
+                           (const char *)rdstation_conf->name());
+    q=new RDSqlQuery(sql);
+    while(q->next()) {
+      services_list.append( q->value(0).toString() );
+    }
     delete q;
+  }
+
+  if(services_list.size()==0) {
     return;
   }
   sql=QString().sprintf("select NAME,DESCRIPTION,SERVICE from LOGS \
                          where (TYPE=0)&&(LOG_EXISTS=\"Y\")&&\
                          ((START_DATE<=\"%s\")||(START_DATE=\"0000-00-00\"))&&\
                          ((END_DATE>=\"%s\")||(END_DATE=\"0000-00-00\"))&&(",
-			(const char *)current_date.toString("yyyy-MM-dd"),
-			(const char *)current_date.toString("yyyy-MM-dd"));
-  while(q->next()) {
+                        (const char *)current_date.toString("yyyy-MM-dd"),
+                        (const char *)current_date.toString("yyyy-MM-dd"));
+  for ( QStringList::Iterator it = services_list.begin(); 
+        it != services_list.end(); ++it ) {
     sql+=QString().sprintf("SERVICE=\"%s\"||",
-			   (const char *)q->value(0).toString());
+                           (const char *)*it);
   }
   sql=sql.left(sql.length()-2);
   sql+=")";
-  delete q;
-  q=new QSqlQuery(sql);
+
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     l=new QListViewItem(list_log_list);
     l->setText(0,q->value(0).toString());
