@@ -101,6 +101,10 @@
         <source>An event is already scheduled with this start time!</source>
         <translation>Um evento já está agendado com esta hora de início!</translation>
     </message>
+    <message>
+        <source>&amp;Recue</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HourSelector</name>
@@ -390,6 +394,10 @@ Log</source>
         <source>Stop</source>
         <translation>Parar</translation>
     </message>
+    <message>
+        <source>ALBUM</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListLogs</name>
@@ -599,7 +607,7 @@ LISTA</translation>
     <name>ModeDisplay</name>
     <message>
         <source>Operating Mode</source>
-        <translation>Modo de Operação</translation>
+        <translation type="unfinished">Modo de Operação</translation>
     </message>
     <message>
         <source>LiveAssist</source>
@@ -614,6 +622,14 @@ LISTA</translation>
         <translation>Manual
 </translation>
     </message>
+    <message>
+        <source>Aux1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Aux2</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PostCounter</name>
