@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcatch.cpp,v 1.120 2008-10-02 18:52:12 fredg Exp $
+//      $Id: rdcatch.cpp,v 1.127.4.8 2014/02/11 23:46:30 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -24,6 +24,7 @@
 #include <vector>
 
 #include <qapplication.h>
+#include <qwindowsstyle.h>
 #include <qwidget.h>
 #include <qpainter.h>
 #include <qsqlpropertymap.h>
@@ -54,6 +55,7 @@
 #include <rdsettings.h>
 #include <rdcmd_switch.h>
 #include <rdedit_audio.h>
+#include <dbversion.h>
 
 #include <add_recording.h>
 #include <edit_recording.h>
@@ -81,6 +83,7 @@ RDCae *catch_cae;
 RDCartDialog *catch_cart_dialog;
 int catch_audition_card=-1;
 int catch_audition_port=-1;
+RDSystem *catch_system=NULL;
 
 //
 // Icons
@@ -98,16 +101,13 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   :QWidget(parent,name)
 {
   QString str;
-  catch_host_warnings=true;
+  catch_host_warnings=false;
   catch_audition_stream=-1;
+  bool skip_db_check=false;
+  unsigned schema=0;
 
   catch_scroll=false;
 
-  //
-  // HACK: Disable the Broken Custom SuSE Dialogs
-  //
-  setenv("QT_NO_KDE_INTEGRATION","1",1);
-
   //
   // Read Command Options
   //
@@ -115,23 +115,14 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
 				   RDCATCH_USAGE);
   for(unsigned i=0;i<cmd->keys();i++) {
     if(cmd->key(i)=="--offline-host-warnings") {
-      if(!RDBool(cmd->value(i))) {
-	catch_host_warnings=false;
-      }
+      catch_host_warnings=RDBool(cmd->value(i));
+    }
+    if(cmd->key(i)=="--skip-db-check") {
+      skip_db_check=true;
     }
   }
   delete cmd;
 
-  //
-  // Ensure Single Instance
-  //
-  catch_lock=new RDInstanceLock(QString().sprintf("%s/.rdcatchlock",
-						 (const char *)RDHomeDir()));
-  if(!catch_lock->lock()) {
-    fprintf(stderr,"rdcatch: multiple instances not allowed\n");
-    exit(1);
-  }
-
   //
   // Fix the Window Size
   //
@@ -195,7 +186,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   catch_config=new RDConfig();
   catch_config->load();
 
-  str=QString(tr("RDCatch - Host:"));
+  str=QString("RDCatch")+" v"+VERSION+" - "+tr("Host")+":";
   setCaption(QString().sprintf("%s %s",(const char *)str,
 			       (const char *)catch_config->stationName()));
 
@@ -203,25 +194,32 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   // Open Database
   //
   QString err (tr("rdcatch : "));
-  catch_db=RDInitDb (&err);
+  catch_db=RDInitDb(&schema,&err);
   if(!catch_db) {
     log(RDConfig::LogErr,err);
     exit(0);
   }
+  if((schema!=RD_VERSION_DATABASE)&&(!skip_db_check)) {
+    fprintf(stderr,"rdcatch: database version mismatch, should be %u, is %u\n",
+	    RD_VERSION_DATABASE,schema);
+    exit(256);
+  }
+
   connect(RDDbStatus(),SIGNAL(logText(RDConfig::LogPriority,const QString &)),
 	  this,SLOT(log(RDConfig::LogPriority,const QString &)));
   //
   // Allocate Global Resources
   //
   rdstation_conf=new RDStation(catch_config->stationName());
+  catch_audition_card=rdstation_conf->cueCard();
+  catch_audition_port=rdstation_conf->cuePort();
   catch_time_offset=rdstation_conf->timeOffset();
+  catch_system=new RDSystem();
 
   //
   // Load Audio Settings
   //
   RDDeck *deck=new RDDeck(catch_config->stationName(),0);
-  catch_audition_card=deck->cardNumber();
-  catch_audition_port=deck->portNumber();
   delete deck;
   head_playing=false;
   tail_playing=false;
@@ -245,12 +243,12 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // CAE Connection
   //
-  catch_cae=new RDCae(this,"catch_cae");
+  catch_cae=new RDCae(rdstation_conf,catch_config,this,"catch_cae");
   connect(catch_cae,SIGNAL(isConnected(bool)),this,SLOT(initData(bool)));
   connect(catch_cae,SIGNAL(playing(int)),this,SLOT(playedData(int)));
   connect(catch_cae,SIGNAL(playStopped(int)),
 	  this,SLOT(playStoppedData(int)));
-  catch_cae->connectHost("localhost",CAED_TCP_PORT,catch_config->password());
+  catch_cae->connectHost();
 
   //
   // Set Audio Assignments
@@ -309,7 +307,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
     catch_station_count++;
 
     sql=QString().sprintf("select CHANNEL,MON_PORT_NUMBER from DECKS \
-where (CARD_NUMBER!=-1)&&(CHANNEL>0)&&(STATION_NAME=\"%s\") \
+where (CARD_NUMBER!=-1)&&(PORT_NUMBER!=-1)&&(CHANNEL>0)&&(STATION_NAME=\"%s\") \
 order by CHANNEL",(const char *)q->value(0).toString().lower());
     q1=new RDSqlQuery(sql);
     while(q1->next()) {
@@ -393,9 +391,9 @@ order by CHANNEL",(const char *)q->value(0).toString().lower());
   // Cart Picker
   //
   catch_cart_dialog=new RDCartDialog(&catch_filter,&catch_group,
-				     catch_audition_card,catch_audition_port,
-				     0,0,catch_cae,catch_ripc,rdstation_conf,
-				     "",this,"catch_cart_dialog");
+				     &catch_schedcode,catch_cae,catch_ripc,
+				     rdstation_conf,catch_system,catch_config,
+				     this);
 
   //
   // Cart List
@@ -932,10 +930,9 @@ void MainWidget::ripcUserData()
 {
   QString str;
 
-  str=QString(tr("RDCatch - Host:"));
-  setCaption(QString().sprintf("%s %s, User: %s",(const char *)str,
-			       (const char *)catch_config->stationName(),
-			       (const char *)catch_ripc->user()));
+  str=QString("RDCatch")+" v"+VERSION+" - "+tr("Host")+":";
+  setCaption(str+" "+catch_config->stationName()+", "+tr("User")+": "+
+	     catch_ripc->user());
   if(catch_user!=NULL) {
     delete catch_user;
   }
@@ -1273,7 +1270,6 @@ void MainWidget::quitMainWidget()
 {
   catch_db->removeDatabase(catch_config->mysqlDbname());
   SaveGeometry();
-  catch_lock->unlock();
   exit(0);
 }
 
@@ -1679,7 +1675,7 @@ void MainWidget::RefreshList()
                RECORDINGS.END_TYPE,RECORDINGS.END_TIME,RECORDINGS.END_LENGTH,\
                RECORDINGS.END_MATRIX,RECORDINGS.END_LINE,CUTS.ORIGIN_NAME,\
                CUTS.ORIGIN_DATETIME,RECORDINGS.URL,RECORDINGS.QUALITY,\
-               FEEDS.KEY_NAME from RECORDINGS left join CUTS\
+               FEEDS.KEY_NAME,EXIT_TEXT from RECORDINGS left join CUTS\
                on (RECORDINGS.CUT_NAME=CUTS.CUT_NAME) left join FEEDS \
                on (RECORDINGS.FEED_ID=FEEDS.ID)");
   // Field Offsets:
@@ -1693,7 +1689,7 @@ void MainWidget::RefreshList()
   //  6 - REC.SUN               24 - REC.MACRO_CART     42 - REC.URL
   //  7 - REC.MON               25 - REC.ID             43 - REC.QUALITY
   //  8 - REC.TUE               26 - REC.TYPE           44 - FEEDS.KEY_NAME
-  //  9 - REC.WED               27 - REC.SWITCH_OUTPUT
+  //  9 - REC.WED               27 - REC.SWITCH_OUTPUT  45 - REC.EXIT_TEXT
   // 10 - REC.THU               28 - REC.EXIT_CODE
   // 11 - REC.FRI               29 - REC.ONE_SHOT
   // 12 - REC.SAT               30 - REC.START_TYPE
@@ -1854,6 +1850,7 @@ void MainWidget::RefreshList()
 		l->setText(20,tr("MPEG Layer 1"));
 		break;
 	      case RDSettings::MpegL2:
+	      case RDSettings::MpegL2Wav:
 		l->setText(20,tr("MPEG Layer 2"));
 		break;
 	      case RDSettings::MpegL3:
@@ -1950,6 +1947,7 @@ void MainWidget::RefreshList()
 		l->setText(20,tr("MPEG Layer 1"));
 		break;
 	      case RDSettings::MpegL2:
+	      case RDSettings::MpegL2Wav:
 		l->setText(20,tr("MPEG Layer 2"));
 		break;
 	      case RDSettings::MpegL3:
@@ -1979,7 +1977,8 @@ void MainWidget::RefreshList()
 	  }
 	  break;
     }
-    DisplayExitCode(l,(RDRecording::ExitCode)q->value(28).toInt());
+    DisplayExitCode(l,(RDRecording::ExitCode)q->value(28).toInt(),
+		    q->value(45).toString());
   }
   delete q;
 }
@@ -2037,7 +2036,8 @@ void MainWidget::RefreshLine(RDListViewItem *item)
                                 CUTS.ORIGIN_DATETIME,\
                                 RECORDINGS.URL,\
                                 RECORDINGS.QUALITY,\
-                                FEEDS.KEY_NAME \
+                                FEEDS.KEY_NAME,\
+                                RECORDINGS.EXIT_TEXT \
                          from RECORDINGS left join CUTS \
                         on (RECORDINGS.CUT_NAME=CUTS.CUT_NAME) left join FEEDS\
                         on (RECORDINGS.FEED_ID=FEEDS.ID) \
@@ -2217,6 +2217,7 @@ void MainWidget::RefreshLine(RDListViewItem *item)
 		item->setText(20,tr("MPEG Layer 1"));
 		break;
 	      case RDSettings::MpegL2:
+	      case RDSettings::MpegL2Wav:
 		item->setText(20,tr("MPEG Layer 2"));
 		break;
 	      case RDSettings::MpegL3:
@@ -2335,6 +2336,7 @@ void MainWidget::RefreshLine(RDListViewItem *item)
 		item->setText(20,tr("MPEG Layer 1"));
 		break;
 	      case RDSettings::MpegL2:
+	      case RDSettings::MpegL2Wav:
 		item->setText(20,tr("MPEG Layer 2"));
 		break;
 	      case RDSettings::MpegL3:
@@ -2360,7 +2362,8 @@ void MainWidget::RefreshLine(RDListViewItem *item)
 	  }
 	  break;
     }
-    DisplayExitCode(item,(RDRecording::ExitCode)q->value(27).toInt());
+    DisplayExitCode(item,(RDRecording::ExitCode)q->value(27).toInt(),
+		    q->value(44).toString());
   }
   else {  // Event removed
     delete item;
@@ -2372,8 +2375,10 @@ void MainWidget::RefreshLine(RDListViewItem *item)
 void MainWidget::UpdateExitCode(RDListViewItem *item)
 {
   RDRecording::ExitCode code=RDRecording::InternalError;
+  QString err_text=tr("Unknown");
   QString sql=QString().sprintf("select RECORDINGS.EXIT_CODE,\
-                                 CUTS.ORIGIN_NAME,CUTS.ORIGIN_DATETIME\
+                                 CUTS.ORIGIN_NAME,CUTS.ORIGIN_DATETIME,\
+                                 RECORDINGS.EXIT_TEXT \
                                  from RECORDINGS left join CUTS \
                                  on RECORDINGS.CUT_NAME=CUTS.CUT_NAME \
                                  where RECORDINGS.ID=%d",
@@ -2381,7 +2386,7 @@ void MainWidget::UpdateExitCode(RDListViewItem *item)
   RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->first()) {
     code=(RDRecording::ExitCode)q->value(0).toInt();
-
+    err_text=q->value(3).toString();
     item->setText(15,q->value(1).toString()+" - "+q->value(2).toDateTime().
 		  toString("M/dd/yyyy hh:mm:ss"));
   }
@@ -2389,76 +2394,39 @@ void MainWidget::UpdateExitCode(RDListViewItem *item)
     item->setText(15,"");
   }
   delete q; 
-  DisplayExitCode(item,code);
+  DisplayExitCode(item,code,err_text);
 }
 
 
 void MainWidget::DisplayExitCode(RDListViewItem *item,
-				 RDRecording::ExitCode code)
+				 RDRecording::ExitCode code,
+				 const QString &err_text)
 {
   item->setText(31,QString().sprintf("%u",code));
   switch(code) {
       case RDRecording::Ok:
-	item->setText(30,tr("OK"));
+      case RDRecording::Downloading:
+      case RDRecording::Uploading:
+      case RDRecording::RecordActive:
+      case RDRecording::PlayActive:
+      case RDRecording::Waiting:
+	item->setText(30,RDRecording::exitString(code));
 	break;
 	
       case RDRecording::Short:
-	item->setText(30,tr("Short Length"));
-	item->setBackgroundColor(EVENT_ERROR_COLOR);
-	break;
-	
       case RDRecording::LowLevel:
-	item->setText(30,tr("Low Level"));
-	item->setBackgroundColor(EVENT_ERROR_COLOR);
-	break;
-	
       case RDRecording::HighLevel:
-	item->setText(30,tr("High Level"));	
+      case RDRecording::Interrupted:
+      case RDRecording::DeviceBusy:
+      case RDRecording::NoCut:
+      case RDRecording::UnknownFormat:
+	item->setText(30,RDRecording::exitString(code));
 	item->setBackgroundColor(EVENT_ERROR_COLOR);
 	break;
 	
-      case RDRecording::Downloading:
-	item->setText(30,tr("Downloading"));
-	break;
-	
-      case RDRecording::Uploading:
-	item->setText(30,tr("Uploading"));
-	break;
-	
-      case RDRecording::RecordActive:
-	item->setText(30,tr("Recording"));
-	break;
-	
-      case RDRecording::PlayActive:
-	item->setText(30,tr("Playing"));
-	break;
-	
-      case RDRecording::Waiting:
-	item->setText(30,tr("Waiting"));
-	break;
-	
       case RDRecording::ServerError:
-	item->setText(30,tr("Server Error"));
-	item->setBackgroundColor(EVENT_ERROR_COLOR);
-	break;
-	
       case RDRecording::InternalError:
-	item->setText(30,tr("Internal Error"));
-	item->setBackgroundColor(EVENT_ERROR_COLOR);
-	break;
-	
-      case RDRecording::Interrupted:
-	item->setText(30,tr("Interrupted"));
-	item->setBackgroundColor(EVENT_ERROR_COLOR);
-	break;
-	
-      case RDRecording::DeviceBusy:
-	item->setText(30,tr("Device Busy"));
-	item->setBackgroundColor(EVENT_ERROR_COLOR);
-	break;
-
-      case RDRecording::NoCut:
-	item->setText(30,tr("No Such Cart/Cut"));
+	item->setText(30,RDRecording::exitString(code)+": "+err_text);
 	item->setBackgroundColor(EVENT_ERROR_COLOR);
 	break;
   }
