@@ -2,9 +2,9 @@
 //
 // CD Ripper Dialog for Rivendell.
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2003,2010 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: disk_ripper.cpp,v 1.23.2.4 2009/09/04 01:29:50 cvs Exp $
+//      $Id: disk_ripper.cpp,v 1.30.4.3.2.1 2014/03/19 22:12:59 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -42,17 +42,24 @@
 #include <rdcut_dialog.h>
 #include <rdlist_groups.h>
 #include <rdgroup.h>
+#include <rdaudioimport.h>
+#include <rdcdripper.h>
+#include <rdescape_string.h>
 
 #include <disk_ripper.h>
 #include <globals.h>
 
 
-DiskRipper::DiskRipper(QString *filter,QString *group,
-		       QWidget *parent,const char *name) 
+DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
+		       bool profile_rip,QWidget *parent,const char *name) 
   : QDialog(parent,name)
 {
+  rip_isrc_read=false;
   rip_filter_text=filter;
   rip_group_text=group;
+  rip_schedcode_text=schedcode;
+  rip_profile_rip=profile_rip;
+  rip_aborting=false;
 
   //
   // Fix the Window Size
@@ -70,10 +77,29 @@ DiskRipper::DiskRipper(QString *filter,QString *group,
 
   setCaption(tr("Rip Disk"));
 
+  //
+  // Create Temporary Directory
+  //
+  char path[PATH_MAX];
+  strncpy(path,RIPPER_TEMP_DIR,PATH_MAX);
+  strcat(path,"/XXXXXX");
+  if(mkdtemp(path)==NULL) {
+    QMessageBox::warning(this,"RDLibrary - "+tr("Ripper Error"),
+			 tr("Unable to create temporary directory!"));
+  }
+  else {
+    rip_cdda_dir.setPath(path);
+  }
+
   //
   // The CDROM Drive
   //
-  rip_cdrom=new RDCdPlayer(this,"rip_cdrom");
+  if(rip_profile_rip) {
+    rip_cdrom=new RDCdPlayer(stdout,this);
+  }
+  else {
+    rip_cdrom=new RDCdPlayer(NULL,this);
+  }
   connect(rip_cdrom,SIGNAL(ejected()),this,SLOT(ejectedData()));
   connect(rip_cdrom,SIGNAL(mediaChanged()),this,SLOT(mediaChangedData()));
   connect(rip_cdrom,SIGNAL(played(int)),this,SLOT(playedData(int)));
@@ -84,7 +110,12 @@ DiskRipper::DiskRipper(QString *filter,QString *group,
   //
   // CDDB Stuff
   //
-  rip_cddb_lookup=new RDCddbLookup(this,"rip_cddb_lookup");
+  if(rip_profile_rip) {
+    rip_cddb_lookup=new RDCddbLookup(stdout,this,"rip_cddb_lookup");
+  }
+  else {
+    rip_cddb_lookup=new RDCddbLookup(NULL,this,"rip_cddb_lookup");
+  }
   connect(rip_cddb_lookup,SIGNAL(done(RDCddbLookup::Result)),
 	  this,SLOT(cddbDoneData(RDCddbLookup::Result)));
 
@@ -173,12 +204,6 @@ DiskRipper::DiskRipper(QString *filter,QString *group,
   rip_trackbar_label->setAlignment(AlignLeft|AlignVCenter);
   rip_trackbar_label->setDisabled(true);
 
-  //
-  // Progress Bar Timer
-  //
-  rip_bar_timer=new QTimer(this,"rip_bar_timer");
-  connect(rip_bar_timer,SIGNAL(timeout()),this,SLOT(barTimerData()));
-
   //
   // Eject Button
   //
@@ -305,6 +330,14 @@ DiskRipper::DiskRipper(QString *filter,QString *group,
 
 DiskRipper::~DiskRipper()
 {
+  QStringList files=rip_cdda_dir.entryList();
+  for(unsigned i=0;i<files.size();i++) {
+    if((files[i]!=".")&&(files[i]!="..")) {
+      rip_cdda_dir.remove(files[i]);
+    }
+  }
+  rmdir(rip_cdda_dir.path());
+
   rip_cdrom->close();
   delete rip_cdrom;
   delete rip_track_list;
@@ -314,7 +347,6 @@ DiskRipper::~DiskRipper()
   delete rip_play_button;
   delete rip_stop_button;
   delete rip_track_bar;
-  delete rip_bar_timer;
 }
 
 
@@ -360,13 +392,43 @@ void DiskRipper::ripDiskButtonData()
   if(item!=NULL) {
     rip_track_list->setSelected(item,false);
   }
+  rip_aborting=false;
+
+  //
+  // Calculate number of tracks to rip
+  //
+  int tracks=0;
   item=rip_track_list->firstChild();
   while(item!=NULL) {
+    if(!item->text(5).isEmpty()) {
+      tracks++;
+    }
+    item=item->nextSibling();
+  }
+  rip_disk_bar->setTotalSteps(tracks);
+
+  //
+  // Read ISRCs
+  //
+  if(!rip_isrc_read) {
+    rip_cddb_lookup->
+      readIsrc(rip_cdda_dir.path(),rdlibrary_conf->ripperDevice());
+    rip_isrc_read=true;
+  }
+
+  //
+  // Rip
+  //
+  tracks=0;
+  item=rip_track_list->firstChild();
+  while((item!=NULL)&&(!rip_aborting)) {
     if(!item->text(5).isEmpty()) {
       rip_eject_button->setDisabled(true);
       rip_play_button->setDisabled(true);
       rip_stop_button->setDisabled(true);
-      rip_rip_button->setDisabled(true);
+      rip_rip_button->setText(tr("Abort\nRip"));
+      disconnect(rip_rip_button,SIGNAL(clicked()),
+		 this,SLOT(ripDiskButtonData()));
       rip_setcut_button->setDisabled(true);
       rip_setall_button->setDisabled(true);
       rip_close_button->setDisabled(true);
@@ -375,15 +437,44 @@ void DiskRipper::ripDiskButtonData()
       rip_channels_box->setDisabled(true);
       rip_autotrim_box->setDisabled(true);
       rip_autotrim_spin->setDisabled(true);
-      rip_base_length=0;
-      rip_disk_bar->setProgress(0,GetTotalLength());
+      rip_disk_bar->setProgress(tracks++);
       rip_disk_bar->setPercentageVisible(true);
       RipTrack(item->text(0).toInt(),rip_cutnames[item->text(0).toInt()-1],
 	       item->text(2));
-      return;
     }
     item=item->nextSibling();
   }
+  rip_eject_button->setEnabled(true);
+  rip_play_button->setEnabled(true);
+  rip_stop_button->setEnabled(true);
+  rip_setcut_button->setEnabled(true);
+  rip_setall_button->setEnabled(true);
+  rip_close_button->setEnabled(true);
+  rip_rip_button->setText(tr("Rip\nDisk"));
+  connect(rip_rip_button,SIGNAL(clicked()),this,SLOT(ripDiskButtonData()));
+  rip_normalize_box->setEnabled(true);
+  rip_normalize_spin->setEnabled(true);
+  rip_channels_box->setEnabled(true);
+  rip_autotrim_box->setEnabled(true);
+  rip_autotrim_spin->setEnabled(true);
+  rip_disk_bar->setPercentageVisible(false);
+  rip_disk_bar->reset();
+  rip_diskbar_label->setDisabled(true);
+  rip_trackbar_label->setDisabled(true);
+  rip_diskbar_label->setText(tr("Total Progress"));
+  rip_trackbar_label->setText(tr("Track Progress"));
+  item=rip_track_list->firstChild();
+  while(item!=NULL) {
+    item->setText(5,"");
+    item=item->nextSibling();
+  }
+  rip_cdrom->eject();
+  if(rip_aborting) {
+    QMessageBox::information(this,tr("Rip Complete"),tr("Rip aborted!"));
+  }
+  else {
+    QMessageBox::information(this,tr("Rip Complete"),tr("Rip complete!"));
+  }
 }
 
 
@@ -407,8 +498,10 @@ void DiskRipper::setCutButtonData()
     return;
   }
   QString cutname=rip_cutnames[item->text(0).toUInt()-1];
-  RDCutDialog *dialog=new RDCutDialog(&cutname,rdstation_conf,rip_filter_text,
-				      rip_group_text,lib_user->name(),true,
+  RDCutDialog *dialog=new RDCutDialog(&cutname,rdstation_conf,lib_system,
+				      rip_filter_text,
+				      rip_group_text,rip_schedcode_text,
+				      lib_user->name(),true,
 				      true,true,this,"cut_dialog");
   if(dialog->exec()==0) {
     if(cutname.isEmpty()) {
@@ -457,8 +550,7 @@ void DiskRipper::setCutButtonData()
       rip_cutnames[item->text(0).toUInt()-1]=cutname;
       RDCart *cart=new RDCart(cutname.left(6).toUInt());
       RDCut *cut=new RDCut(cutname);
-      item->setText(5,QString().sprintf("%s -> %s",(const char *)cart->title(),
-					(const char *)cut->description()));
+      item->setText(5,cart->title()+" -> "+cut->description());
       delete cut;
       delete cart;
     }
@@ -510,10 +602,8 @@ void DiskRipper::setAllButtonData()
 void DiskRipper::mediaChangedData()
 {
   QListViewItem *l;
-  QString cdda_dir=tempnam(RIPPER_TEMP_DIR,"cdda");
-
-  mkdir(cdda_dir,0700);
 
+  rip_isrc_read=false;
   rip_cutnames.clear();
   rip_track_list->clear();
   rip_track=-1;
@@ -532,11 +622,10 @@ void DiskRipper::mediaChangedData()
   rip_cddb_record.clear();
   rip_cdrom->setCddbRecord(&rip_cddb_record);
   rip_cddb_lookup->setCddbRecord(&rip_cddb_record);
-  rip_cddb_lookup->lookupRecord(cdda_dir,rdlibrary_conf->ripperDevice(),
-				rdlibrary_conf->cddbServer(),8880,
-				RIPPER_CDDB_USER,PACKAGE_NAME,VERSION);
-  system(QString().sprintf("rm %s/*",(const char *)cdda_dir));
-  system(QString().sprintf("rmdir %s",(const char *)cdda_dir));
+  rip_cddb_lookup->
+    lookupRecord(rip_cdda_dir.path(),rdlibrary_conf->ripperDevice(),
+		 rdlibrary_conf->cddbServer(),8880,
+		 RIPPER_CDDB_USER,PACKAGE_NAME,VERSION);
 }
 
 
@@ -580,7 +669,6 @@ void DiskRipper::cddbDoneData(RDCddbLookup::Result result)
 	break;
       default:
 	rip_track=-1;
-	printf("No Match!\n");
 	break;
   }
 }
@@ -602,98 +690,6 @@ void DiskRipper::autotrimCheckData(bool state)
 }
 
 
-void DiskRipper::barTimerData()
-{
-  if(ripper_running) {
-    rip_track_bar->setProgress((int)(50.0*((double)bar_temp_file->
-					   size()/(double)rip_temp_length+
-					   (double)bar_file->size()/
-					   (double)rip_finished_length)));
-    rip_disk_bar->setProgress(rip_base_length+bar_temp_file->size()+
-			      bar_file->size());
-    rip_bar_timer->start(RIPPER_BAR_INTERVAL,true);
-  }
-  else {
-    rip_track_bar->setPercentageVisible(false);
-    rip_track_bar->reset();
-    if(bar_file->exists()) {
-      rip_done=true;
-      QListViewItem *item=rip_track_list->firstChild();
-      rip_base_length+=(rip_temp_length+rip_finished_length);
-      rip_disk_bar->setProgress(rip_base_length);
-      RDCut *cut=new RDCut(rip_cutname);
-      cut->reset();
-      cut->setOriginName(rdstation_conf->name());
-      RDCart *cart=new RDCart(rip_cutname.left(6).toUInt());
-      cart->updateLength();
-      cart->resetRotation();
-      if(rip_apply_box->isChecked()&&(!rip_title.isEmpty())) {
-	cart->setTitle(rip_title);
-	cart->setArtist(rip_artist_edit->text());
-	cut->setDescription(rip_title);
-	cut->setIsrc(rip_cddb_record.isrc(rip_track_number-1));
-      }
-      if(rip_done&&rip_autotrim_box->isChecked()) {
-	AutoTrim();
-      }
-      delete cart;
-      delete cut;
-      while(item!=NULL) {
-	if((item->text(0).toInt()>rip_track_number)&&
-	   (!item->text(5).isEmpty())) {
-	  RipTrack(item->text(0).toInt(),
-		   rip_cutnames[item->text(0).toInt()-1],item->text(2));
-	  return;
-	}
-	item=item->nextSibling();
-      }
-      rip_cdrom->eject();
-      QMessageBox::information(this,tr("Rip Complete"),
-			       tr("Rip complete!"));
-    }
-    else {
-      rip_cdrom->eject();
-      if(rip_rip_aborted) {
-	QMessageBox::information(this,tr("Rip Aborted"),
-				 tr("The rip has been aborted."));
-
-      }
-      else {
-	QMessageBox::warning(this,tr("Rip Failed"),
-			     tr("The ripper encountered an error.\n\
-Please check your ripper configuration and try again."));
-      }
-    }
-    rip_eject_button->setEnabled(true);
-    rip_play_button->setEnabled(true);
-    rip_stop_button->setEnabled(true);
-    rip_setcut_button->setEnabled(true);
-    rip_setall_button->setEnabled(true);
-    rip_close_button->setEnabled(true);
-    rip_normalize_box->setEnabled(true);
-    rip_normalize_spin->setEnabled(true);
-    rip_channels_box->setEnabled(true);
-    rip_autotrim_box->setEnabled(true);
-    rip_autotrim_spin->setEnabled(true);
-    rip_disk_bar->setPercentageVisible(false);
-    rip_disk_bar->reset();
-    rip_diskbar_label->setDisabled(true);
-    rip_trackbar_label->setDisabled(true);
-    rip_diskbar_label->setText(tr("Total Progress"));
-    rip_trackbar_label->setText(tr("Track Progress"));
-    QListViewItem *item=rip_track_list->firstChild();
-    while(item!=NULL) {
-      item->setText(5,"");
-      item=item->nextSibling();
-    }
-    delete bar_file;
-    delete bar_temp_file;
-    bar_file=NULL;
-    bar_temp_file=NULL;
-  }
-}
-
-
 void DiskRipper::resizeEvent(QResizeEvent *e)
 {
   rip_artist_edit->setGeometry(65,9,size().width()-125,18);
@@ -757,188 +753,131 @@ void DiskRipper::closeEvent(QCloseEvent *e)
 
 void DiskRipper::RipTrack(int track,QString cutname,QString title)
 {
-  bool rc;
-  mode_t prev_mask;
-  QString cmd;
-  unsigned cartnum=cutname.left(6).toUInt();
+  RDCdRipper *ripper=NULL;
+  RDCut *cut=new RDCut(cutname);
+  RDCart *cart=new RDCart(cut->cartNumber());
   QString sql=QString().sprintf("select NUMBER from CART where NUMBER=%u",
-				cartnum);
+				cut->cartNumber());
   RDSqlQuery *q=new RDSqlQuery(sql);
   if(!q->first()) {  // Create Cart/cut entries
     delete q;
-    sql=QString().sprintf("insert into CART set \
-                           NUMBER=%u,TYPE=%d,GROUP_NAME=\"%s\",\
-                           TITLE=\"[New Cart %06u]\",CUT_QUANTITY=1",
-			  cartnum,RDCart::Audio,
-			  (const char *)(*rip_group_text),cartnum);
+    sql=QString("insert into CART set ")+
+      QString().sprintf("NUMBER=%u,TYPE=%d,",cut->cartNumber(),RDCart::Audio)+
+      "GROUP_NAME=\""+RDEscapeString(*rip_group_text)+"\","+
+      "CUT_QUANTITY=1";
+
     q=new RDSqlQuery(sql);
     delete q;
-    sql=QString().sprintf("insert into CUTS set\
-                           CUT_NAME=\"%s\",CART_NUMBER=%u,\
-                           DESCRIPTION=\"Cut 001\"",
-			  (const char *)cutname,cartnum);
-    q=new RDSqlQuery(sql);
+    sql=QString("insert into CUTS set ")+
+      "CUT_NAME=\""+RDEscapeString(cutname)+"\","+
+      QString().sprintf("CART_NUMBER=%u,",cut->cartNumber())+
+      "DESCRIPTION=\""+tr("Cut")+" 001\"";
+      q=new RDSqlQuery(sql);
   }
   delete q;
   
   rip_done=false;
   rip_rip_aborted=false;
-  rip_wavefile=RDCut::pathName(cutname); 
   rip_track_number=track;
   rip_title=title;
   rip_cutname=cutname;
-  bar_file=new QFile(rip_wavefile);
-  prev_mask = umask(0113);      // Set umask so files are user and group writable.
-  rc=bar_file->open(IO_WriteOnly);
-  umask(prev_mask);
-  if(!rc) {
-    QMessageBox::warning(this,tr("No Access"),
-			 tr("Unable to open the file for writing!"),
-			 tr("OK"));
-    delete bar_file;
-    return;
-  }
-  bar_file->close();
-
   if(title.isEmpty()) {
-    rip_trackbar_label->
-      setText(QString().sprintf("%s - Track %d",
-				(const char *)tr("Track Progress"),track));
+    rip_trackbar_label->setText(tr("Track Progress")+" - "+tr("Track")+
+				QString().sprintf(" %d",track));
   }
   else {
-    rip_trackbar_label->
-      setText(QString().sprintf("%s - %s",
-				(const char *)tr("Track Progress"),
-				(const char *)title));
+    rip_trackbar_label->setText(tr("Track Progress")+" - "+title);
   }
   rip_diskbar_label->setEnabled(true);
   rip_trackbar_label->setEnabled(true);
 
-  rip_temp_length=(int)((double)rip_cdrom->trackLength(track)*176.4);
-  switch(rdlibrary_conf->defaultFormat()) {
-      case 0:  // PCM16
-	rip_finished_length=
-	  (int)(((double)rip_temp_length/2.0)*
-		(double)(rip_channels_box->currentItem()+1.0)*
-		(double)rdlibrary_conf->defaultSampleRate()/44100.0);
-	break;
-      case 1:  // MPEG-1 Layer 2
-      case 2:  // MPEG-1 Layer 3
-	rip_finished_length=
-	  (int)((double)rip_temp_length*
-		(double)(rip_channels_box->currentItem()+1)*
-		(double)rdlibrary_conf->defaultBitrate()/1411200.0);
-	break;
-  }
-  if(rip_normalize_box->isChecked()) {
-    cmd=QString().
-      sprintf("rd_rip_cd %d %s %d %6.4lf %d %d %d %d %s %s/%s %s/%s %d",
-	      rip_track_number,
-	      (const char *)rdlibrary_conf->ripperDevice(),
-	      rdlibrary_conf->paranoiaLevel(),
-	      pow(10.0,(double)(rip_normalize_spin->value())/20.0),
-	      rdlibrary_conf->defaultFormat(),
-	      rip_channels_box->currentItem()+1,
-	      rdlibrary_conf->defaultSampleRate(),
-	      (rip_channels_box->currentItem()+1)*
-	      rdlibrary_conf->defaultBitrate()/1000, 
-	      (const char *)rip_wavefile,
-	      RIPPER_TEMP_DIR,
-	      RIPPER_TEMP_PEAK,
-	      RIPPER_TEMP_DIR,
-	      RIPPER_TEMP_WAV,
-	      rdlibrary_conf->srcConverter());
+  //
+  // Rip from disc
+  //
+  RDAudioImport::ErrorCode conv_err;
+  RDAudioConvert::ErrorCode audio_conv_err;
+  RDCdRipper::ErrorCode ripper_err;
+  QString tmpdir=RDTempDir();
+  QString tmpfile=tmpdir+"/"+RIPPER_TEMP_WAV;
+  if(rip_profile_rip) {
+    ripper=new RDCdRipper(stdout,this);
   }
   else {
-    cmd=QString().
-      sprintf("rd_rip_cd %d %s %d 0 %d %d %d %d %s %s/%s %s/%s %d",
-	      rip_track_number,
-	      (const char *)rdlibrary_conf->ripperDevice(),
-	      rdlibrary_conf->paranoiaLevel(),
-	      rdlibrary_conf->defaultFormat(),
-	      rip_channels_box->currentItem()+1,
-	      rdlibrary_conf->defaultSampleRate(),
-	      (rip_channels_box->currentItem()+1)*
-	      rdlibrary_conf->defaultBitrate()/1000,
-	      (const char *)rip_wavefile,
-	      RIPPER_TEMP_DIR,
-	      RIPPER_TEMP_PEAK,
-	      RIPPER_TEMP_DIR,
-	      RIPPER_TEMP_WAV,
-	      rdlibrary_conf->srcConverter());
+    ripper=new RDCdRipper(NULL,this);
   }
-  ripper_running=true;
-  bar_temp_file=new QFile(QString(RIPPER_TEMP_DIR)+QString("/")+
-			  QString(RIPPER_TEMP_WAV));
-  if((rip_ripper_pid=fork())==0) {
-    if(system(cmd)!=0) {
-      bar_file->remove();
+  rip_track_bar->setTotalSteps(ripper->totalSteps()+1);
+  connect(ripper,SIGNAL(progressChanged(int)),
+	  rip_track_bar,SLOT(setProgress(int)));
+  connect(rip_rip_button,SIGNAL(clicked()),ripper,SLOT(abort()));
+  RDAudioImport *conv=NULL;
+  RDSettings *settings=NULL;
+  ripper->setDevice(rdlibrary_conf->ripperDevice());
+  ripper->setDestinationFile(tmpfile);
+  switch((ripper_err=ripper->rip(rip_track_number-1))) {
+  case RDCdRipper::ErrorOk:
+    conv=new RDAudioImport(rdstation_conf,lib_config,this);
+    conv->setSourceFile(tmpfile);
+    conv->setCartNumber(cut->cartNumber());
+    conv->setCutNumber(cut->cutNumber());
+    conv->setUseMetadata(false);
+    settings=new RDSettings();
+    if(rdlibrary_conf->defaultFormat()==1) {
+      settings->setFormat(RDSettings::MpegL2Wav);
     }
-    exit(0);
+    else {
+      settings->setFormat(RDSettings::Pcm16);
+    }
+    settings->setChannels(rip_channels_box->currentText().toInt());
+    settings->setSampleRate(lib_system->sampleRate());
+    settings->setBitRate(rdlibrary_conf->defaultBitrate());
+    if(rip_normalize_box->isChecked()) {
+      settings->setNormalizationLevel(rip_normalize_spin->value());
+    }
+    if(rip_autotrim_box->isChecked()) {
+      settings->setAutotrimLevel(rip_autotrim_spin->value());
+    }
+    conv->setDestinationSettings(settings);
+    switch((conv_err=conv->
+	    runImport(lib_user->name(),lib_user->password(),
+		      &audio_conv_err))) {
+    case RDAudioImport::ErrorOk:
+      if(rip_apply_box->isChecked()&&(!rip_title.isEmpty())) {
+	cart->setTitle(rip_title);
+	cart->setArtist(rip_artist_edit->text());
+	cart->setAlbum(rip_album_edit->text());
+	cut->setDescription(rip_title);
+	cut->setIsrc(rip_cddb_record.isrc(rip_track_number-1));
+      }
+      break;
+
+    default:
+      QMessageBox::warning(this,tr("RDLibrary - Importer Error"),
+			   RDAudioImport::errorText(conv_err,audio_conv_err));
+      break;
+    }
+    delete settings;
+    delete conv;
+    break;
+
+  case RDCdRipper::ErrorNoDevice:
+  case RDCdRipper::ErrorNoDestination:
+  case RDCdRipper::ErrorInternal:
+  case RDCdRipper::ErrorNoDisc:
+  case RDCdRipper::ErrorNoTrack:
+    QMessageBox::warning(this,tr("RDLibrary - Ripper Error"),
+			 RDCdRipper::errorText(ripper_err));
+    break;
+
+  case RDCdRipper::ErrorAborted:
+    rip_aborting=true;
+    break;
   }
+  delete ripper;
+  unlink(tmpfile);
+  rmdir(tmpdir);
   rip_track_bar->setProgress(0);
   rip_track_bar->setPercentageVisible(true);
-  rip_bar_timer->start(RIPPER_BAR_INTERVAL,true);
-}
 
-
-int DiskRipper::GetTotalLength()
-{
-  unsigned raw_length=0;
-  QListViewItem *item=rip_track_list->firstChild();
-  while(item!=NULL) {
-    if(!item->text(5).isEmpty()) {
-      raw_length+=(unsigned)((double)rip_cdrom->
-			 trackLength(item->text(0).toInt())*176.4);
-    }
-    item=item->nextSibling();
-  }
-  switch(rdlibrary_conf->defaultFormat()) {
-      case 0:  // PCM16
-	return (int)(((double)raw_length/2.0)*
-		     (double)(rip_channels_box->currentItem()+1.0)*
-		     (double)rdlibrary_conf->defaultSampleRate()/44100.0)+
-	  raw_length;
-	break;
-      case 1:  // MPEG-1 Layer 2
-      case 2:  // MPEG-1 Layer 3
-	return (int)((double)raw_length*
-		     (double)(rip_channels_box->currentItem()+1)*
-		     (double)rdlibrary_conf->defaultBitrate()/1411200.0)+
-	  raw_length;
-	break;
-  }
-  return 0;
-}
-
-
-void DiskRipper::AutoTrim()
-{
-  int point;
-
-  RDCut *cut=new RDCut(rip_cutname);
-  if(!cut->exists()) {
-    delete cut;
-    return;
-  }
-  RDWaveFile *wave=new RDWaveFile(rip_wavefile);
-  if(!wave->openWave()) {
-    delete wave;
-    delete cut;
-    return;
-  }
-  if((point=wave->
-      startTrim(-rip_autotrim_spin->value()*100+REFERENCE_LEVEL))>-1) {
-    cut->setStartPoint((int)(1000.0*(double)point/
-			     (double)wave->getSamplesPerSec()));
-  }
-  if((point=wave->
-      endTrim(-rip_autotrim_spin->value()*100+REFERENCE_LEVEL))>-1) {
-    cut->setEndPoint((int)(1000.0*(double)point/
-			     (double)wave->getSamplesPerSec()));
-  }
-  cut->setLength(cut->endPoint()-cut->startPoint());
-  delete wave;
+  delete cart;
   delete cut;
 }
-
