@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2010 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlibrary.cpp,v 1.117.4.7 2013/12/31 22:49:48 cvs Exp $
+//      $Id: rdlibrary.cpp,v 1.117.4.18.2.1 2014/03/19 22:12:59 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -26,6 +26,7 @@
 #include <sys/wait.h>
 
 #include <qapplication.h>
+#include <qwindowsstyle.h>
 #include <qeventloop.h>
 #include <qwidget.h>
 #include <qpainter.h>
@@ -53,6 +54,7 @@
 #include <rdcheck_daemons.h>
 #include <rdtextvalidator.h>
 #include <rdcmd_switch.cpp>
+#include <rdescape_string.h>
 #include <dbversion.h>
 
 #include <filter.h>
@@ -99,14 +101,29 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
 {
   unsigned schema=0;
   bool skip_db_check=false;
+  profile_ripping=false;
+  lib_edit_pending=false;
+  lib_user_changed=false;
 
   //
   // Read Command Options
   //
-  RDCmdSwitch *cmd=new RDCmdSwitch(qApp->argc(),qApp->argv(),"rdlibrary","\n");
+  RDCmdSwitch *cmd=
+    new RDCmdSwitch(qApp->argc(),qApp->argv(),"rdlibrary",RDLIBRARY_USAGE);
   for(unsigned i=0;i<cmd->keys();i++) {
     if(cmd->key(i)=="--skip-db-check") {
       skip_db_check=true;
+      cmd->setProcessed(i,true);
+    }
+    if(cmd->key(i)=="--profile-ripping") {
+      profile_ripping=true;
+      cmd->setProcessed(i,true);
+    }
+    if(!cmd->processed(i)) {
+      QMessageBox::warning(this,"RDLibrary - "+tr("Error"),
+			   tr("Unknown command-line option")+
+			   " \""+cmd->key(i)+"\".");
+      exit(256);
     }
   }
   delete cmd;
@@ -202,6 +219,8 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   rdripc->connectHost("localhost",RIPCD_TCP_PORT,lib_config->password());
   cut_clipboard=NULL;
   lib_system=new RDSystem();
+  lib_user_timer=new QTimer(this);
+  connect(lib_user_timer,SIGNAL(timeout()),this,SLOT(userData()));
 
   //
   // CAE Connection
@@ -291,6 +310,10 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   lib_allowdrag_label->setAlignment(AlignVCenter|AlignLeft);
   connect(lib_allowdrag_box,SIGNAL(stateChanged(int)),
 	  this,SLOT(dragsChangedData(int)));
+  if(!rdstation_conf->enableDragdrop()) {
+    lib_allowdrag_box->hide();
+    lib_allowdrag_label->hide();
+  }
 
   //
   // Show Audio Carts Checkbox
@@ -330,8 +353,6 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   // Show Matches Checkbox
   //
   lib_showmatches_box=new QCheckBox(this,"lib_showmatches_box");
-  lib_showmatches_box->setChecked(true);
-  lib_showmatches_box->setChecked(true);
   lib_showmatches_label=
     new QLabel(lib_showmatches_box,tr("Show Only First ")+
 	       QString().sprintf("%d",RD_LIMITED_CART_SEARCH_QUANTITY)+
@@ -340,7 +361,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   lib_showmatches_label->setFont(button_font);
   lib_showmatches_label->setAlignment(AlignVCenter|AlignLeft);
   connect(lib_showmatches_box,SIGNAL(stateChanged(int)),
-	  this,SLOT(macroChangedData(int)));
+	  this,SLOT(searchLimitChangedData(int)));
 
   //
   // Cart List
@@ -381,6 +402,10 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   lib_cart_list->addColumn(tr("END"));
   lib_cart_list->setColumnAlignment(7,Qt::AlignHCenter);
 
+  lib_cart_list->addColumn(tr("ALBUM"));
+
+  lib_cart_list->addColumn(tr("LABEL"));
+
   lib_cart_list->addColumn(tr("COMPOSER"));
 
   lib_cart_list->addColumn(tr("CONDUCTOR"));
@@ -394,26 +419,23 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   lib_cart_list->addColumn(tr("USER DEFINED"));
 
   lib_cart_list->addColumn(tr("CUTS"));
-  lib_cart_list->setColumnAlignment(14,Qt::AlignRight);
+  lib_cart_list->setColumnAlignment(16,Qt::AlignRight);
 
   lib_cart_list->addColumn(tr("LAST CUT PLAYED"));
-  lib_cart_list->setColumnAlignment(15,Qt::AlignHCenter);
-
-  //  lib_cart_list->addColumn(tr("PLAY ORDER"));
-  //  lib_cart_list->setColumnAlignment(16,Qt::AlignHCenter);
-
-  lib_cart_list->addColumn(tr("ENFORCE LENGTH"));
-  lib_cart_list->setColumnAlignment(16,Qt::AlignHCenter);
-
-  lib_cart_list->addColumn(tr("PRESERVE PITCH"));
   lib_cart_list->setColumnAlignment(17,Qt::AlignHCenter);
 
-  lib_cart_list->addColumn(tr("LENGTH DEVIATION"));
+  lib_cart_list->addColumn(tr("ENFORCE LENGTH"));
   lib_cart_list->setColumnAlignment(18,Qt::AlignHCenter);
 
-  lib_cart_list->addColumn(tr("OWNED BY"));
+  lib_cart_list->addColumn(tr("PRESERVE PITCH"));
   lib_cart_list->setColumnAlignment(19,Qt::AlignHCenter);
 
+  lib_cart_list->addColumn(tr("LENGTH DEVIATION"));
+  lib_cart_list->setColumnAlignment(20,Qt::AlignHCenter);
+
+  lib_cart_list->addColumn(tr("OWNED BY"));
+  lib_cart_list->setColumnAlignment(21,Qt::AlignHCenter);
+
   //
   // Add Button
   //
@@ -474,6 +496,23 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   ::signal(SIGCHLD,SigHandler);
 
+  //
+  // Load Data
+  //
+  switch(rdlibrary_conf->limitSearch()) {
+  case RDLibraryConf::LimitNo:
+    lib_showmatches_box->setChecked(false);
+    break;
+
+  case RDLibraryConf::LimitYes:
+    lib_showmatches_box->setChecked(true);
+    break;
+
+  case RDLibraryConf::LimitPrevious:
+    lib_showmatches_box->setChecked(rdlibrary_conf->searchLimited());
+    break;
+  }
+
   LoadGeometry();
 }
 
@@ -500,6 +539,11 @@ void MainWidget::userData()
   QString sql;
   RDSqlQuery *q;
 
+  if(lib_edit_pending) {
+    lib_user_changed=true;
+    return;
+  }
+
   SetCaption(rdripc->user());
   if(lib_user!=NULL) {
     delete lib_user;
@@ -508,15 +552,13 @@ void MainWidget::userData()
 
   lib_group_box->clear();
   lib_group_box->insertItem(tr("ALL"));
-  sql=QString().sprintf("select GROUP_NAME from USER_PERMS\
-                              where USER_NAME=\"%s\" order by GROUP_NAME",
-			     (const char *)lib_user->name());
+  sql=QString("select GROUP_NAME from USER_PERMS where ")+
+    "USER_NAME=\""+RDEscapeString(lib_user->name())+"\" order by GROUP_NAME";
   q=new RDSqlQuery(sql);
   while(q->next()) {
     lib_group_box->insertItem(q->value(0).toString());
   }
   delete q;
-  groupActivatedData(lib_group_box->currentText());
 
   if(lib_group_box->count()==1) {
     lib_add_button->setDisabled(true);
@@ -539,8 +581,8 @@ void MainWidget::userData()
     lib_codes_box->insertItem(q->value(0).toString());
   }
   delete q;
-  RefreshList();
   lib_search_button->setDisabled(true);
+  groupActivatedData(lib_group_box->currentText());
 }
 
 
@@ -590,24 +632,27 @@ void MainWidget::addData()
   int cart_num;
   RDCart::Type cart_type=RDCart::All;
   QString cart_title;
-  
+
+  LockUser();
+
   RDAddCart *add_cart=new RDAddCart(&lib_default_group,&cart_type,&cart_title,
 				    lib_user->name(),lib_system,
 				    this,"add_cart");
   if((cart_num=add_cart->exec())<0) {
     delete add_cart;
+    UnlockUser();
     return;
   }
   delete add_cart;
-  sql=QString().sprintf("insert into CART set \
-                         NUMBER=%u,TYPE=%d,GROUP_NAME=\"%s\",TITLE=\"%s\"",
-			cart_num,cart_type,
-			(const char *)lib_default_group,
-			(const char *)cart_title);
+  sql=QString("insert into CART set ")+
+    QString().sprintf("NUMBER=%u,TYPE=%d,",cart_num,cart_type)+
+    "GROUP_NAME=\""+RDEscapeString(lib_default_group)+"\","+
+    "TITLE=\""+RDEscapeString(cart_title)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
   
-  EditCart *cart=new EditCart(cart_num,&lib_import_path,true,this);
+  EditCart *cart=
+    new EditCart(cart_num,&lib_import_path,true,profile_ripping,this);
   if(cart->exec() <0) {
     RDCart *rdcart=new RDCart(cart_num);
     rdcart->remove(rdstation_conf,lib_user,lib_config);
@@ -626,6 +671,8 @@ void MainWidget::addData()
     lib_cart_list->ensureItemVisible(item);
   }
   delete cart;
+
+  UnlockUser();
 }
 
 
@@ -635,6 +682,8 @@ void MainWidget::editData()
   int sel_count=0;
   QListViewItemIterator *it;
 
+  LockUser();
+
   it=new QListViewItemIterator(lib_cart_list);
   while(it->current()) {
     if (it->current()->isSelected()) {
@@ -645,6 +694,7 @@ void MainWidget::editData()
   delete it;
 
   if(sel_count==0) {
+    UnlockUser();
     return;
   }
   if(sel_count==1) { //single edit
@@ -655,7 +705,7 @@ void MainWidget::editData()
     RDListViewItem *item=(RDListViewItem *)it->current();
 
     EditCart *edit_cart=new EditCart(item->text(1).toUInt(),&lib_import_path,
-				     false,this,"edit_cart");
+				     false,profile_ripping,this);
     edit_cart->exec();
     RefreshLine(item);
     cartOnItemData(item);
@@ -663,10 +713,10 @@ void MainWidget::editData()
     delete it;
   }
   else { //multi edit
-  //  RDListViewItem *item=(RDListViewItem *)it->current();
     if(lib_user->modifyCarts()) {
-      EditCart *edit_cart=new EditCart(0,&lib_import_path,
-				     false,this,"edit_cart",lib_cart_list);
+      EditCart *edit_cart=
+	new EditCart(0,&lib_import_path,false,profile_ripping,this,"",
+				       lib_cart_list);
     
       edit_cart->exec();
       delete edit_cart;
@@ -679,9 +729,9 @@ void MainWidget::editData()
         ++(*it);
       }
       delete it;
- //   RefreshLine(item);
     }
   }
+  UnlockUser();
 }
 
 
@@ -695,11 +745,8 @@ void MainWidget::deleteData()
   QListViewItemIterator *it;
   bool del_flag;
 
-//  RDListViewItem *item=(RDListViewItem *)lib_cart_list->selectedItem();
-//
-//  if(item==NULL) {
-//    return;
-//  }
+  LockUser();
+
   it=new QListViewItemIterator(lib_cart_list);
   while(it->current()) {
     if (it->current()->isSelected()) {
@@ -710,12 +757,14 @@ void MainWidget::deleteData()
   delete it;
 
   if(sel_count==0) {
+    UnlockUser();
     return;
   }
 
   str=QString(tr("Are you sure you want to delete cart(s)"));
   if(QMessageBox::question(this,tr("Delete Cart(s)"),str,QMessageBox::Yes,QMessageBox::No)!=
      QMessageBox::Yes) {
+    UnlockUser();
     return;
   }
   it=new QListViewItemIterator(lib_cart_list);
@@ -754,7 +803,7 @@ Do you still want to delete it?"),item->text(1).toUInt());
       cut_clipboard=NULL;
     }
   }
-  if(del_flag && item->text(19).isEmpty()) {
+  if(del_flag && item->text(21).isEmpty()) {
     RDCart *rdcart=new RDCart(item->text(1).toUInt());
     if(!rdcart->remove(rdstation_conf,lib_user,lib_config)) {
       QMessageBox::warning(this,tr("RDLibrary"),tr("Unable to delete audio!"));
@@ -772,15 +821,18 @@ Do you still want to delete it?"),item->text(1).toUInt());
     } 
   }
   delete it;
+
+  UnlockUser();
 }
 
 
 void MainWidget::ripData()
 {
+  LockUser();
   QString group=lib_group_box->currentText();
   QString schedcode=lib_codes_box->currentText();
   DiskRipper *dialog=new DiskRipper(&lib_filter_text,&group,&schedcode,
-				    this,"disk_ripper");
+				    profile_ripping,this,"disk_ripper");
   if(dialog->exec()==0) {
     for(int i=0;i<lib_group_box->count();i++) {
       if(lib_group_box->text(i)==*group) {
@@ -791,18 +843,22 @@ void MainWidget::ripData()
     }
   }
   delete dialog;
-  RefreshList();
+  if(!UnlockUser()) {
+    RefreshList();
+  }
 }
 
 
 void MainWidget::reportsData()
 {
+  LockUser();
   ListReports *lr=
     new ListReports(lib_filter_edit->text(),GetTypeFilter(),
 		    lib_group_box->currentText(),lib_codes_box->currentText(),
 		    this,"lr");
   lr->exec();
   delete lr;
+  UnlockUser();
 }
 
 
@@ -826,7 +882,7 @@ void MainWidget::cartClickedData(QListViewItem *item)
   while(it->current()) {
     if (it->current()->isSelected()) {
       sel_count++;
-      if(it->current()->text(19).isEmpty()) {
+      if(it->current()->text(21).isEmpty()) {
         del_count++;
       }
     }
@@ -872,6 +928,13 @@ void MainWidget::macroChangedData(int state)
 }
 
 
+void MainWidget::searchLimitChangedData(int state)
+{
+  rdlibrary_conf->setSearchLimited(state);
+  filterChangedData("");
+}
+
+
 void MainWidget::dragsChangedData(int state)
 {
   if(state) {
@@ -929,7 +992,7 @@ void MainWidget::resizeEvent(QResizeEvent *e)
   lib_add_button->setGeometry(10,e->size().height()-60,80,50);
   lib_edit_button->setGeometry(100,e->size().height()-60,80,50);
   lib_delete_button->setGeometry(190,e->size().height()-60,80,50);
-  disk_gauge->setGeometry(285,e->size().height()-45,
+  disk_gauge->setGeometry(285,e->size().height()-55,
 			  e->size().width()-585,
 			  disk_gauge->sizeHint().height());
   lib_rip_button->
@@ -959,7 +1022,48 @@ void MainWidget::RefreshList()
     return;
   }
 
+  //
+  // 00 - CART.NUMBER
+  // 01 - CART.FORCED_LENGTH
+  // 02 - CART.TITLE
+  // 03 - CART.ARTIST
+  // 04 - CART.ALBUM
+  // 05 - CART.LABEL
+  // 06 - CART.CLIENT
+  // 07 - CART.AGENCY
+  // 08 - CART.USER_DEFINED
+  // 09 - CART.COMPOSER
+  // 10 - CART.PUBLISHER
+  // 11 - CART.CONDUCTOR
+  // 12 - CART.GROUP_NAME
+  // 13 - CART.START_DATETIME
+  // 14 - CART.END_DATETIME
+  // 15 - CART.TYPE
+  // 16 - CART.CUT_QUANTITY
+  // 17 - CART.LAST_CUT_PLAYED
+  // 18 - CART.ENFORCE_LENGTH
+  // 19 - CART.PRESERVE_PITCH
+  // 20 - CART.LENGTH_DEVIATION
+  // 21 - CART.OWNER
+  // 22 - CART.VALIDITY
+  // 23 - GROUPS.COLOR
+  // 24 - CUTS.LENGTH
+  // 25 - CUTS.EVERGREEN
+  // 26 - CUTS.START_DATETIME
+  // 27 - CUTS.END_DATETIME
+  // 28 - CUTS.START_DAYPART
+  // 29 - CUTS.END_DAYPART
+  // 30 - CUTS.MON
+  // 31 - CUTS.TUE
+  // 32 - CUTS.WED
+  // 33 - CUTS.THU
+  // 34 - CUTS.FRI
+  // 35 - CUTS.SAT
+  // 36 - CUTS.SUN
+  //
+
   sql="select CART.NUMBER,CART.FORCED_LENGTH,CART.TITLE,CART.ARTIST,\
+       CART.ALBUM,CART.LABEL,\
        CART.CLIENT,CART.AGENCY,CART.USER_DEFINED,\
        CART.COMPOSER,CART.PUBLISHER,CART.CONDUCTOR,\
        CART.GROUP_NAME,CART.START_DATETIME,CART.END_DATETIME,CART.TYPE,\
@@ -976,21 +1080,15 @@ void MainWidget::RefreshList()
     schedcode=lib_codes_box->currentText();
   }
   if(lib_group_box->currentText()==QString(tr("ALL"))) {
-    sql+=QString().
-      sprintf(" where %s && %s",
-	      (const char *)RDAllCartSearchText(lib_filter_edit->text(),
-						schedcode,
-						lib_user->name(),true).utf8(),
-	      (const char *)type_filter);
+    sql+=QString(" where ")+
+      RDAllCartSearchText(lib_filter_edit->text(),schedcode,
+			  lib_user->name(),true)+" && "+type_filter;
+
   }
   else {
-    sql+=QString().
-      sprintf(" where %s && %s",
-	      (const char *)RDCartSearchText(lib_filter_edit->text(),
-					     lib_group_box->currentText(),
-					     schedcode,true).
-	      utf8(),
-	      (const char *)type_filter);
+    sql+=QString(" where ")+
+      RDCartSearchText(lib_filter_edit->text(),lib_group_box->currentText(),
+		       schedcode,true)+" && "+type_filter;      
   }
   sql+=" order by CART.NUMBER";
   if(lib_showmatches_box->isChecked()) {
@@ -1002,34 +1100,34 @@ void MainWidget::RefreshList()
   lib_progress_dialog->setTotalSteps(q->size()/RDLIBRARY_STEP_SIZE);
   lib_progress_dialog->setProgress(0);
   while(q->next()) {
-    end_datetime=q->value(12).toDateTime();
+    end_datetime=q->value(14).toDateTime();
     if(q->value(0).toUInt()==cartnum) {
-      if((RDCart::Type)q->value(13).toUInt()==RDCart::Macro) {
+      if((RDCart::Type)q->value(15).toUInt()==RDCart::Macro) {
 	validity=RDCart::AlwaysValid;
       }
       else {
-	validity=ValidateCut(q,22,validity,current_datetime);
+	validity=ValidateCut(q,24,validity,current_datetime);
       }
     }
     else {
       //
       // Write availability color
       //
-      UpdateItemColor(l,validity,q->value(12).toDateTime(),current_datetime);
+      UpdateItemColor(l,validity,q->value(14).toDateTime(),current_datetime);
 
       //
       // Start a new entry
       //
-      if((RDCart::Type)q->value(13).toUInt()==RDCart::Macro) {
+      if((RDCart::Type)q->value(15).toUInt()==RDCart::Macro) {
 	validity=RDCart::AlwaysValid;
       }
       else {
-	validity=ValidateCut(q,22,RDCart::NeverValid,current_datetime);
+	validity=ValidateCut(q,24,RDCart::NeverValid,current_datetime);
       }
       l=new RDListViewItem(lib_cart_list);
-      switch((RDCart::Type)q->value(13).toUInt()) {
+      switch((RDCart::Type)q->value(15).toUInt()) {
       case RDCart::Audio:
-	if(q->value(19).isNull()) {
+	if(q->value(21).isNull()) {
 	  l->setPixmap(0,*lib_playout_map);
 	}
 	else {
@@ -1046,41 +1144,43 @@ void MainWidget::RefreshList()
 	break;
       }
       l->setText(1,QString().sprintf("%06d",q->value(0).toUInt()));
-      l->setText(2,q->value(10).toString());
-      l->setTextColor(2,q->value(21).toString(),QFont::Bold);
+      l->setText(2,q->value(12).toString());
+      l->setTextColor(2,q->value(23).toString(),QFont::Bold);
       l->setText(3,RDGetTimeLength(q->value(1).toUInt()));
       l->setText(4,q->value(2).toString());
       l->setText(5,q->value(3).toString());
-      if(!q->value(11).toDateTime().isNull()) {
-	l->setText(6,q->value(11).toDateTime().
+      if(!q->value(13).toDateTime().isNull()) {
+	l->setText(6,q->value(13).toDateTime().
 		   toString("MM/dd/yyyy - hh:mm:ss"));
       }
-      if(!q->value(12).toDateTime().isNull()) {
-	l->setText(7,q->value(12).toDateTime().
+      if(!q->value(14).toDateTime().isNull()) {
+	l->setText(7,q->value(14).toDateTime().
 		   toString("MM/dd/yyyy - hh:mm:ss"));
       }
       else {
 	l->setText(7,"TFN");
       }
-      l->setText(8,q->value(7).toString());
-      l->setText(9,q->value(9).toString());
-      l->setText(10,q->value(8).toString());
-      l->setText(11,q->value(4).toString());
-      l->setText(12,q->value(5).toString());
+      l->setText(8,q->value(4).toString());
+      l->setText(9,q->value(5).toString());
+      l->setText(10,q->value(9).toString());
+      l->setText(11,q->value(11).toString());
+      l->setText(12,q->value(10).toString());
       l->setText(13,q->value(6).toString());
-      l->setText(14,q->value(14).toString());
-      l->setText(15,q->value(15).toString());
+      l->setText(14,q->value(7).toString());
+      l->setText(15,q->value(8).toString());
       l->setText(16,q->value(16).toString());
       l->setText(17,q->value(17).toString());
       l->setText(18,q->value(18).toString());
       l->setText(19,q->value(19).toString());
-      if(q->value(16).toString()=="Y") {
+      l->setText(20,q->value(20).toString());
+      l->setText(21,q->value(21).toString());
+      if(q->value(18).toString()=="Y") {
 	l->setTextColor(3,QColor(RDLIBRARY_ENFORCE_LENGTH_COLOR),QFont::Bold);
       }
       else {
-	if((q->value(18).toUInt()>RDLIBRARY_MID_LENGTH_LIMIT)&&
-	   (q->value(16).toString()=="N")) {
-	  if(q->value(18).toUInt()>RDLIBRARY_MAX_LENGTH_LIMIT) {
+	if((q->value(20).toUInt()>RDLIBRARY_MID_LENGTH_LIMIT)&&
+	   (q->value(18).toString()=="N")) {
+	  if(q->value(20).toUInt()>RDLIBRARY_MAX_LENGTH_LIMIT) {
 	    l->setTextColor(3,QColor(RDLIBRARY_MAX_LENGTH_COLOR),QFont::Bold);
 	  }
 	  else {
@@ -1128,7 +1228,9 @@ void MainWidget::RefreshLine(RDListViewItem *item)
   RDCart::Validity validity=RDCart::NeverValid;
   QDateTime current_datetime(QDate::currentDate(),QTime::currentTime());
   QString sql=QString().sprintf("select CART.FORCED_LENGTH,CART.TITLE,\
-                                 CART.ARTIST,CART.CLIENT,\
+                                 CART.ARTIST,\
+                                 CART.ALBUM,CART.LABEL,\
+                                 CART.CLIENT,\
                                  CART.AGENCY,CART.USER_DEFINED,\
                                  CART.COMPOSER,CART.CONDUCTOR,CART.PUBLISHER,\
                                  CART.GROUP_NAME,CART.START_DATETIME,\
@@ -1149,15 +1251,15 @@ void MainWidget::RefreshLine(RDListViewItem *item)
 				item->text(1).toUInt());
   RDSqlQuery *q=new RDSqlQuery(sql);
   while(q->next()) {
-    if((RDCart::Type)q->value(12).toUInt()==RDCart::Macro) {
+    if((RDCart::Type)q->value(14).toUInt()==RDCart::Macro) {
       validity=RDCart::AlwaysValid;
     }
     else {
-      validity=ValidateCut(q,21,validity,current_datetime);
+      validity=ValidateCut(q,23,validity,current_datetime);
     }
-    switch((RDCart::Type)q->value(12).toUInt()) {
+    switch((RDCart::Type)q->value(14).toUInt()) {
 	case RDCart::Audio:
-	  if(q->value(18).isNull()) {
+	  if(q->value(20).isNull()) {
 	    item->setPixmap(0,*lib_playout_map);
 	  }
 	  else {
@@ -1167,8 +1269,8 @@ void MainWidget::RefreshLine(RDListViewItem *item)
 	    item->setBackgroundColor(RD_CART_ERROR_COLOR);
 	  }
 	  else {
-	    UpdateItemColor(item,(RDCart::Validity)q->value(19).toUInt(),
-			    q->value(11).toDateTime(),current_datetime);
+	    UpdateItemColor(item,(RDCart::Validity)q->value(21).toUInt(),
+			    q->value(13).toDateTime(),current_datetime);
 	  }
 	  break;
 
@@ -1179,43 +1281,46 @@ void MainWidget::RefreshLine(RDListViewItem *item)
     case RDCart::All:
 	  break;
     }
-    item->setText(2,q->value(9).toString());
-    item->setTextColor(2,q->value(20).toString(),QFont::Bold);
+    item->setText(2,q->value(11).toString());
+    item->setTextColor(2,q->value(22).toString(),QFont::Bold);
     item->setText(3,RDGetTimeLength(q->value(0).toUInt()));
     item->setText(4,q->value(1).toString());
     item->setText(5,q->value(2).toString());
-    item->setText(8,q->value(6).toString());
-    item->setText(9,q->value(7).toString());
-    item->setText(11,q->value(3).toString());
-    item->setText(12,q->value(4).toString());
+    item->setText(8,q->value(3).toString());
+    item->setText(9,q->value(4).toString());
+    item->setText(10,q->value(8).toString());
+    item->setText(11,q->value(9).toString());
+
+    item->setText(12,q->value(10).toString());
     item->setText(13,q->value(5).toString());
-    if(!q->value(10).toDateTime().isNull()) {
-      item->setText(6,q->value(10).toDateTime().
+    item->setText(14,q->value(6).toString());
+    if(!q->value(12).toDateTime().isNull()) {
+      item->setText(6,q->value(12).toDateTime().
 		    toString("MM/dd/yyyy - hh:mm:ss"));
     }
     else {
       item->setText(6,"");
     }
-    if(!q->value(11).toDateTime().isNull()) {
-      item->setText(7,q->value(11).toDateTime().
+    if(!q->value(13).toDateTime().isNull()) {
+      item->setText(7,q->value(13).toDateTime().
 		    toString("MM/dd/yyyy - hh:mm:ss"));
     }
     else {
       item->setText(7,tr("TFN"));
     }
-    item->setText(14,q->value(13).toString());
-    item->setText(15,q->value(14).toString());
     item->setText(16,q->value(15).toString());
     item->setText(17,q->value(16).toString());
     item->setText(18,q->value(17).toString());
     item->setText(19,q->value(18).toString());
-    if(q->value(15).toString()=="Y") {
+    item->setText(20,q->value(19).toString());
+    item->setText(21,q->value(20).toString());
+    if(q->value(17).toString()=="Y") {
       item->setTextColor(3,QColor(RDLIBRARY_ENFORCE_LENGTH_COLOR),QFont::Bold);
     }
     else {
-      if((q->value(17).toUInt()>RDLIBRARY_MID_LENGTH_LIMIT)&&
-	 (q->value(15).toString()=="N")) {
-	if(q->value(17).toUInt()>RDLIBRARY_MAX_LENGTH_LIMIT) {
+      if((q->value(19).toUInt()>RDLIBRARY_MID_LENGTH_LIMIT)&&
+	 (q->value(17).toString()=="N")) {
+	if(q->value(19).toUInt()>RDLIBRARY_MAX_LENGTH_LIMIT) {
 	  item->setTextColor(3,QColor(RDLIBRARY_MAX_LENGTH_COLOR),QFont::Bold);
 	}
 	else {
@@ -1348,6 +1453,24 @@ void MainWidget::SaveGeometry()
 }
 
 
+void MainWidget::LockUser()
+{
+  lib_edit_pending=true;
+}
+
+
+bool MainWidget::UnlockUser()
+{
+  bool ret=lib_user_changed;
+  lib_edit_pending=false;
+  if(lib_user_changed) {
+    lib_user_timer->start(0,true);
+    lib_user_changed=false;
+  }
+  return ret;
+}
+
+
 int main(int argc,char *argv[])
 {
   QApplication a(argc,argv);
