@@ -69,10 +69,6 @@
         <source>NAME</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Cuts</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Cut Info</source>
         <translation type="unfinished"></translation>
@@ -115,11 +111,6 @@ Markers</source>
         <source>RDCatch Event Exists</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>This cut is used in one or more RDCatch events!
-Do you still want to delete it?</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Empty Clipboard</source>
         <translation type="unfinished"></translation>
@@ -158,20 +149,53 @@ Do you want to proceed?</source>
         <source>None</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>1 Cut</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>RDLibrary</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Unable to delete audio!</source>
+        <source>No audio is present in the cut!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>No audio is present in the cut!</source>
+        <source>This cart cannot contain any additional cuts!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>RDLibrary - Edit Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete Cuts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>cuts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>One or more cuts are used in one or more RDCatch events!
+Do you still want to delete?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to delete audio for cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No data copied - you must select a single cut!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Paste Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You must select a single cut!</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -293,6 +317,22 @@ Rip</source>
         <source>Rip Track</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Title:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[none]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ripper Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to create temporary directory!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DiskRipper</name>
@@ -467,6 +507,22 @@ Disk</source>
         <source>Rip aborted!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Ripper Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to create temporary directory!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Track</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditCart</name>
@@ -621,6 +677,34 @@ limits of the system!  Do you still want to save?</source>
 Notes</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>RDLibrary - Edit Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This cart cannot contain any additional cuts!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cond&amp;uctor:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Song &amp;ID:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Beats per Minute:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use Event Length for Now &amp;&amp; Next Updates</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditMacro</name>
@@ -720,10 +804,6 @@ Notes</source>
         <source>Cut Report</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Cart Data Dump</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Type:</source>
         <translation type="unfinished"></translation>
@@ -740,6 +820,18 @@ Notes</source>
         <source>ALL</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Cart Data Dump (fixed width)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart Data Dump (CSV)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Prepend Field Names</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MacroCart</name>
@@ -880,10 +972,6 @@ Cart</source>
         <source>LAST CUT PLAYED</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>PLAY ORDER</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>ENFORCE LENGTH</source>
         <translation type="unfinished"></translation>
@@ -959,14 +1047,6 @@ Do you still want to delete it?</source>
         <source>Empty Clipboard</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Sequence</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Random</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>TFN</source>
         <translation type="unfinished"></translation>
@@ -999,6 +1079,38 @@ Do you still want to delete it?</source>
         <source>User</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>COMPOSER</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>CONDUCTOR</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PUBLISHER</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow Cart Dragging</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown command-line option</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ALBUM</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LABEL</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RecordCut</name>
