@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlogmanager.cpp,v 1.37 2008/07/26 00:01:39 fredg Exp $
+//      $Id: rdlogmanager.cpp,v 1.43.4.4 2014/01/21 21:59:32 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -28,6 +28,7 @@
 #include <sys/wait.h>
 #endif  // WIN32
 #include <qapplication.h>
+#include <qwindowsstyle.h>
 #include <qwidget.h>
 #include <qpainter.h>
 #include <qsqldatabase.h>
@@ -45,10 +46,15 @@
 #include <rduser.h>
 #include <rdripc.h>
 #include <rdstation.h>
+#include <rdsvc.h>
 #include <rdcheck_daemons.h>
 #include <rdcreate_log.h>
 #include <rdcmd_switch.h>
 #include <rddbheartbeat.h>
+#include <rddatedecode.h>
+#include <rdlog.h>
+#include <rdlog_event.h>
+#include <dbversion.h>
 
 #include <rdlogmanager.h>
 #include <globals.h>
@@ -58,7 +64,6 @@
 #include <generate_log.h>
 #include <list_svcs.h>
 
-
 //
 // Icons
 //
@@ -71,8 +76,10 @@ RDStation *rdstation_conf;
 RDUser *rduser;
 RDRipc *rdripc;
 RDCae *rdcae;
+RDConfig *log_config;
 QString *event_filter;
 QString *clock_filter;
+bool skip_db_check=false;
 
 
 #ifndef WIN32
@@ -94,48 +101,9 @@ void SigHandler(int signo)
 
 
 MainWidget::MainWidget(QWidget *parent,const char *name)
-  :QDialog(parent,name)
+  :QWidget(parent,name)
 {
-  //
-  // HACK: Disable the Broken Custom SuSE Dialogs
-  //
-#ifndef WIN32
-  setenv("QT_NO_KDE_INTEGRATION","1",1);
-#endif  // WIN32
-
-  //
-  // Read Command Options
-  //
-  bool cmd_generate = false;
-  bool cmd_merge_music = false;
-  bool cmd_merge_traffic = false;
-  QString cmd_service = NULL;
-  QDate cmd_date = QDate::currentDate().addDays(1);
-
-  RDCmdSwitch *cmd=
-    new RDCmdSwitch(qApp->argc(),qApp->argv(),"rdlogmanager","\n");
-  for(unsigned i=0;i<cmd->keys();i++)
-     {
-     if (cmd->key(i)=="-g")
-       cmd_generate = true;
-     if (cmd->key(i)=="-m")
-       cmd_merge_music = true;
-     if (cmd->key(i)=="-t")
-       cmd_merge_traffic = true;
-     if (cmd->key(i)=="-s")
-       if (i+1<cmd->keys())
-         {
-         i++;
-         cmd_service = cmd->key(i);
-         }
-     if (cmd->key(i)=="-d")
-       if (i+1<cmd->keys())
-         {
-         i++;
-         cmd_date = QDate::currentDate().addDays(cmd->key(i).toInt());
-         }
-    }
-  delete cmd;
+  unsigned schema=0;
 
   //
   // Fix the Window Size
@@ -163,11 +131,22 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   // Open Database
   //
   QString err;
-  log_db=RDInitDb(&err);
+  log_db=RDInitDb(&schema,&err);
   if(!log_db) {
     QMessageBox::warning(this,tr("Can't Connect"),err);
     exit(0);
   }
+  if((schema!=RD_VERSION_DATABASE)&&(!skip_db_check)) {
+#ifdef WIN32
+	    QMessageBox::warning(this,tr("RDLogEdit -- Database Skew"),
+				 tr("This version of RDLogManager is incompatible with the version installed on the server.\nSee your system administrator for an update!"));
+#else
+    fprintf(stderr,
+	    "rdlogmanager: database version mismatch, should be %u, is %u\n",
+	    RD_VERSION_DATABASE,schema);
+#endif  // WIN32
+    exit(256);
+  }
   new RDDbHeartbeat(log_config->mysqlHeartbeatInterval(),this);
 
   //
@@ -179,8 +158,8 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   // CAE Connection
   //
 #ifndef WIN32
-  rdcae=new RDCae(parent,name);
-  rdcae->connectHost("localhost",CAED_TCP_PORT,log_config->password());
+  rdcae=new RDCae(rdstation_conf,log_config,parent,name);
+  rdcae->connectHost();
 #endif  // WIN32
 
   //
@@ -288,24 +267,6 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   log_close_button->setDefault(true);
   connect(log_close_button,SIGNAL(clicked()),this,SLOT(quitMainWidget()));
 
-  if (cmd_generate)
-    {
-    GenerateLog *generatelog=new GenerateLog(this,"list_grids",1,&cmd_service,&cmd_date);
-    delete generatelog;
-    }
-  if (cmd_merge_music)
-    {
-    GenerateLog *generatelog=new GenerateLog(this,"list_grids",2,&cmd_service,&cmd_date);
-    delete generatelog;
-    }
-  if (cmd_merge_traffic)
-    {
-    GenerateLog *generatelog=new GenerateLog(this,"list_grids",3,&cmd_service,&cmd_date);
-    delete generatelog;
-    }
-   if (cmd_generate || cmd_merge_music ||cmd_merge_traffic )
-    quitMainWidget();
-
 #ifndef WIN32
   signal(SIGCHLD,SigHandler);
 #endif  // WIN32
@@ -396,7 +357,7 @@ void MainWidget::quitMainWidget()
 }
 
 
-int main(int argc,char *argv[])
+int gui_main(int argc,char *argv[])
 {
   QApplication a(argc,argv);
   
@@ -413,7 +374,7 @@ int main(int argc,char *argv[])
 			    readEntry("/Rivendell/InstallDir"));
   qt_path=tr_path;
 #else
-  tr_path=QString(PREFIX)+QString("/share/srlabs/");
+  tr_path=QString(PREFIX)+QString("/share/rivendell/");
   qt_path=QString(QTDIR)+QString("/translation/");
 #endif  // WIN32
   QTranslator qt(0);
@@ -444,3 +405,93 @@ int main(int argc,char *argv[])
 }
 
 
+int main(int argc,char *argv[])
+{
+  //
+  // Read Command Options
+  //
+  bool cmd_generate=false;
+  bool cmd_merge_music=false;
+  bool cmd_merge_traffic=false;
+  QString cmd_service=NULL;
+  QString cmd_report=NULL;
+  int cmd_start_offset=0;
+  int cmd_end_offset=0;
+  QDate cmd_start_date = QDate::currentDate().addDays(1);
+
+  RDCmdSwitch *cmd=
+    new RDCmdSwitch(argc,argv,"rdlogmanager",RDLOGMANAGER_USAGE);
+  for(unsigned i=0;i<cmd->keys();i++) {
+    if (cmd->key(i)=="-g") {
+      cmd_generate = true;
+    }
+    if (cmd->key(i)=="-m") {
+      cmd_merge_music = true;
+    }
+    if (cmd->key(i)=="-t") {
+      cmd_merge_traffic = true;
+      cmd->setProcessed(i,true);
+    }
+    if(cmd->key(i)=="--skip-db-check") {
+      skip_db_check=true;
+      cmd->setProcessed(i,true);
+    }
+    if (cmd->key(i)=="-s") {
+      if (i+1<cmd->keys()) {
+	i++;
+	cmd_service = cmd->key(i);
+      }
+      else {
+	fprintf(stderr,"rdlogmanager: missing argument to \"-s\"\n");
+	exit(256);
+      }
+    }
+    if (cmd->key(i)=="-r") {
+      if (i+1<cmd->keys()) {
+	i++;
+	cmd_report = cmd->key(i);
+      }
+      else {
+	fprintf(stderr,"rdlogmanager: missing argument to \"-r\"\n");
+	exit(256);
+      }
+    }
+    if (cmd->key(i)=="-d") {
+      if (i+1<cmd->keys()) {
+	i++;
+	cmd_start_offset=cmd->key(i).toInt();
+      }
+      else {
+	fprintf(stderr,"rdlogmanager: missing argument to \"-d\"\n");
+	exit(256);
+      }
+    }
+    if (cmd->key(i)=="-e") {
+      if (i+1<cmd->keys()) {
+	i++;
+	cmd_end_offset=cmd->key(i).toInt();
+      }
+      else {
+	fprintf(stderr,"rdlogmanager: missing argument to \"-e\"\n");
+	exit(256);
+      }
+    }
+  }
+  delete cmd;
+  if((!cmd_report.isNull())&&
+     (cmd_generate||cmd_merge_traffic||cmd_merge_music)) {
+    fprintf(stderr,
+	    "rdlogmanager: log and report operations are mutually exclusive\n");
+    exit(256);
+  }
+
+  if(cmd_generate||cmd_merge_traffic||cmd_merge_music) {
+    return RunLogOperation(argc,argv,cmd_service,cmd_start_offset,cmd_generate,
+			   cmd_merge_music,cmd_merge_traffic);
+  }
+  if(!cmd_report.isEmpty()) {
+    return RunReportOperation(argc,argv,cmd_report,cmd_start_offset,
+			      cmd_end_offset);
+  }
+  return gui_main(argc,argv);
+}
